# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class GetAICoachCheatDetectionResponseBody(DaraModel):
    def __init__(
        self,
        cheat_id: str = None,
        error_code: str = None,
        error_message: str = None,
        gmt_create: str = None,
        image_cheat: main_models.GetAICoachCheatDetectionResponseBodyImageCheat = None,
        request_id: str = None,
        status: int = None,
        success: bool = None,
        voice_cheat: main_models.GetAICoachCheatDetectionResponseBodyVoiceCheat = None,
    ):
        self.cheat_id = cheat_id
        self.error_code = error_code
        self.error_message = error_message
        self.gmt_create = gmt_create
        self.image_cheat = image_cheat
        # Id of the request
        self.request_id = request_id
        self.status = status
        # true
        self.success = success
        self.voice_cheat = voice_cheat

    def validate(self):
        if self.image_cheat:
            self.image_cheat.validate()
        if self.voice_cheat:
            self.voice_cheat.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.cheat_id is not None:
            result['cheatId'] = self.cheat_id

        if self.error_code is not None:
            result['errorCode'] = self.error_code

        if self.error_message is not None:
            result['errorMessage'] = self.error_message

        if self.gmt_create is not None:
            result['gmtCreate'] = self.gmt_create

        if self.image_cheat is not None:
            result['imageCheat'] = self.image_cheat.to_map()

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.status is not None:
            result['status'] = self.status

        if self.success is not None:
            result['success'] = self.success

        if self.voice_cheat is not None:
            result['voiceCheat'] = self.voice_cheat.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('cheatId') is not None:
            self.cheat_id = m.get('cheatId')

        if m.get('errorCode') is not None:
            self.error_code = m.get('errorCode')

        if m.get('errorMessage') is not None:
            self.error_message = m.get('errorMessage')

        if m.get('gmtCreate') is not None:
            self.gmt_create = m.get('gmtCreate')

        if m.get('imageCheat') is not None:
            temp_model = main_models.GetAICoachCheatDetectionResponseBodyImageCheat()
            self.image_cheat = temp_model.from_map(m.get('imageCheat'))

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('status') is not None:
            self.status = m.get('status')

        if m.get('success') is not None:
            self.success = m.get('success')

        if m.get('voiceCheat') is not None:
            temp_model = main_models.GetAICoachCheatDetectionResponseBodyVoiceCheat()
            self.voice_cheat = temp_model.from_map(m.get('voiceCheat'))

        return self

class GetAICoachCheatDetectionResponseBodyVoiceCheat(DaraModel):
    def __init__(
        self,
        comparison_list: List[main_models.GetAICoachCheatDetectionResponseBodyVoiceCheatComparisonList] = None,
        desc: str = None,
        original_list: List[main_models.GetAICoachCheatDetectionResponseBodyVoiceCheatOriginalList] = None,
        status: int = None,
    ):
        self.comparison_list = comparison_list
        self.desc = desc
        self.original_list = original_list
        self.status = status

    def validate(self):
        if self.comparison_list:
            for v1 in self.comparison_list:
                 if v1:
                    v1.validate()
        if self.original_list:
            for v1 in self.original_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['comparisonList'] = []
        if self.comparison_list is not None:
            for k1 in self.comparison_list:
                result['comparisonList'].append(k1.to_map() if k1 else None)

        if self.desc is not None:
            result['desc'] = self.desc

        result['originalList'] = []
        if self.original_list is not None:
            for k1 in self.original_list:
                result['originalList'].append(k1.to_map() if k1 else None)

        if self.status is not None:
            result['status'] = self.status

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.comparison_list = []
        if m.get('comparisonList') is not None:
            for k1 in m.get('comparisonList'):
                temp_model = main_models.GetAICoachCheatDetectionResponseBodyVoiceCheatComparisonList()
                self.comparison_list.append(temp_model.from_map(k1))

        if m.get('desc') is not None:
            self.desc = m.get('desc')

        self.original_list = []
        if m.get('originalList') is not None:
            for k1 in m.get('originalList'):
                temp_model = main_models.GetAICoachCheatDetectionResponseBodyVoiceCheatOriginalList()
                self.original_list.append(temp_model.from_map(k1))

        if m.get('status') is not None:
            self.status = m.get('status')

        return self

class GetAICoachCheatDetectionResponseBodyVoiceCheatOriginalList(DaraModel):
    def __init__(
        self,
        url: str = None,
    ):
        self.url = url

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.url is not None:
            result['url'] = self.url

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('url') is not None:
            self.url = m.get('url')

        return self

class GetAICoachCheatDetectionResponseBodyVoiceCheatComparisonList(DaraModel):
    def __init__(
        self,
        time: str = None,
        url: str = None,
    ):
        self.time = time
        self.url = url

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.time is not None:
            result['time'] = self.time

        if self.url is not None:
            result['url'] = self.url

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('time') is not None:
            self.time = m.get('time')

        if m.get('url') is not None:
            self.url = m.get('url')

        return self

class GetAICoachCheatDetectionResponseBodyImageCheat(DaraModel):
    def __init__(
        self,
        desc: str = None,
        list: List[main_models.GetAICoachCheatDetectionResponseBodyImageCheatList] = None,
        status: int = None,
    ):
        self.desc = desc
        self.list = list
        self.status = status

    def validate(self):
        if self.list:
            for v1 in self.list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.desc is not None:
            result['desc'] = self.desc

        result['list'] = []
        if self.list is not None:
            for k1 in self.list:
                result['list'].append(k1.to_map() if k1 else None)

        if self.status is not None:
            result['status'] = self.status

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('desc') is not None:
            self.desc = m.get('desc')

        self.list = []
        if m.get('list') is not None:
            for k1 in m.get('list'):
                temp_model = main_models.GetAICoachCheatDetectionResponseBodyImageCheatList()
                self.list.append(temp_model.from_map(k1))

        if m.get('status') is not None:
            self.status = m.get('status')

        return self

class GetAICoachCheatDetectionResponseBodyImageCheatList(DaraModel):
    def __init__(
        self,
        time: str = None,
        url: str = None,
    ):
        self.time = time
        self.url = url

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.time is not None:
            result['time'] = self.time

        if self.url is not None:
            result['url'] = self.url

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('time') is not None:
            self.time = m.get('time')

        if m.get('url') is not None:
            self.url = m.get('url')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetOssUploadTokenRequest(DaraModel):
    def __init__(
        self,
        file_name: str = None,
        file_type: str = None,
        upload_type: int = None,
    ):
        # This parameter is required.
        self.file_name = file_name
        # This parameter is required.
        self.file_type = file_type
        self.upload_type = upload_type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.file_name is not None:
            result['fileName'] = self.file_name

        if self.file_type is not None:
            result['fileType'] = self.file_type

        if self.upload_type is not None:
            result['uploadType'] = self.upload_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('fileName') is not None:
            self.file_name = m.get('fileName')

        if m.get('fileType') is not None:
            self.file_type = m.get('fileType')

        if m.get('uploadType') is not None:
            self.upload_type = m.get('uploadType')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class CreateTrainTaskRequest(DaraModel):
    def __init__(
        self,
        aliyun_main_id: str = None,
        res_spec_type: str = None,
        task_type: str = None,
        use_scene: str = None,
        voice_gender: str = None,
        voice_language: str = None,
        voice_name: str = None,
        voice_path: str = None,
    ):
        self.aliyun_main_id = aliyun_main_id
        self.res_spec_type = res_spec_type
        self.task_type = task_type
        self.use_scene = use_scene
        self.voice_gender = voice_gender
        self.voice_language = voice_language
        self.voice_name = voice_name
        self.voice_path = voice_path

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.aliyun_main_id is not None:
            result['aliyunMainId'] = self.aliyun_main_id

        if self.res_spec_type is not None:
            result['resSpecType'] = self.res_spec_type

        if self.task_type is not None:
            result['taskType'] = self.task_type

        if self.use_scene is not None:
            result['useScene'] = self.use_scene

        if self.voice_gender is not None:
            result['voiceGender'] = self.voice_gender

        if self.voice_language is not None:
            result['voiceLanguage'] = self.voice_language

        if self.voice_name is not None:
            result['voiceName'] = self.voice_name

        if self.voice_path is not None:
            result['voicePath'] = self.voice_path

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('aliyunMainId') is not None:
            self.aliyun_main_id = m.get('aliyunMainId')

        if m.get('resSpecType') is not None:
            self.res_spec_type = m.get('resSpecType')

        if m.get('taskType') is not None:
            self.task_type = m.get('taskType')

        if m.get('useScene') is not None:
            self.use_scene = m.get('useScene')

        if m.get('voiceGender') is not None:
            self.voice_gender = m.get('voiceGender')

        if m.get('voiceLanguage') is not None:
            self.voice_language = m.get('voiceLanguage')

        if m.get('voiceName') is not None:
            self.voice_name = m.get('voiceName')

        if m.get('voicePath') is not None:
            self.voice_path = m.get('voicePath')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class BatchGetTrainTaskResponseBody(DaraModel):
    def __init__(
        self,
        request_id: str = None,
        voice_list: List[main_models.BatchGetTrainTaskResponseBodyVoiceList] = None,
    ):
        self.request_id = request_id
        self.voice_list = voice_list

    def validate(self):
        if self.voice_list:
            for v1 in self.voice_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.request_id is not None:
            result['requestId'] = self.request_id

        result['voiceList'] = []
        if self.voice_list is not None:
            for k1 in self.voice_list:
                result['voiceList'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        self.voice_list = []
        if m.get('voiceList') is not None:
            for k1 in m.get('voiceList'):
                temp_model = main_models.BatchGetTrainTaskResponseBodyVoiceList()
                self.voice_list.append(temp_model.from_map(k1))

        return self

class BatchGetTrainTaskResponseBodyVoiceList(DaraModel):
    def __init__(
        self,
        aliyun_sub_id: str = None,
        audit_fail_message: str = None,
        audit_status: str = None,
        create_time: str = None,
        gender: str = None,
        name: str = None,
        res_spec_type: str = None,
        task_id: str = None,
        task_type: str = None,
        train_fail_message: str = None,
        train_status: str = None,
        use_scene: str = None,
        voice_material: main_models.BatchGetTrainTaskResponseBodyVoiceListVoiceMaterial = None,
    ):
        self.aliyun_sub_id = aliyun_sub_id
        self.audit_fail_message = audit_fail_message
        self.audit_status = audit_status
        self.create_time = create_time
        self.gender = gender
        self.name = name
        self.res_spec_type = res_spec_type
        self.task_id = task_id
        self.task_type = task_type
        self.train_fail_message = train_fail_message
        self.train_status = train_status
        self.use_scene = use_scene
        self.voice_material = voice_material

    def validate(self):
        if self.voice_material:
            self.voice_material.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.aliyun_sub_id is not None:
            result['aliyunSubId'] = self.aliyun_sub_id

        if self.audit_fail_message is not None:
            result['auditFailMessage'] = self.audit_fail_message

        if self.audit_status is not None:
            result['auditStatus'] = self.audit_status

        if self.create_time is not None:
            result['createTime'] = self.create_time

        if self.gender is not None:
            result['gender'] = self.gender

        if self.name is not None:
            result['name'] = self.name

        if self.res_spec_type is not None:
            result['resSpecType'] = self.res_spec_type

        if self.task_id is not None:
            result['taskId'] = self.task_id

        if self.task_type is not None:
            result['taskType'] = self.task_type

        if self.train_fail_message is not None:
            result['trainFailMessage'] = self.train_fail_message

        if self.train_status is not None:
            result['trainStatus'] = self.train_status

        if self.use_scene is not None:
            result['useScene'] = self.use_scene

        if self.voice_material is not None:
            result['voiceMaterial'] = self.voice_material.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('aliyunSubId') is not None:
            self.aliyun_sub_id = m.get('aliyunSubId')

        if m.get('auditFailMessage') is not None:
            self.audit_fail_message = m.get('auditFailMessage')

        if m.get('auditStatus') is not None:
            self.audit_status = m.get('auditStatus')

        if m.get('createTime') is not None:
            self.create_time = m.get('createTime')

        if m.get('gender') is not None:
            self.gender = m.get('gender')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('resSpecType') is not None:
            self.res_spec_type = m.get('resSpecType')

        if m.get('taskId') is not None:
            self.task_id = m.get('taskId')

        if m.get('taskType') is not None:
            self.task_type = m.get('taskType')

        if m.get('trainFailMessage') is not None:
            self.train_fail_message = m.get('trainFailMessage')

        if m.get('trainStatus') is not None:
            self.train_status = m.get('trainStatus')

        if m.get('useScene') is not None:
            self.use_scene = m.get('useScene')

        if m.get('voiceMaterial') is not None:
            temp_model = main_models.BatchGetTrainTaskResponseBodyVoiceListVoiceMaterial()
            self.voice_material = temp_model.from_map(m.get('voiceMaterial'))

        return self

class BatchGetTrainTaskResponseBodyVoiceListVoiceMaterial(DaraModel):
    def __init__(
        self,
        voice_id: int = None,
        voice_language: str = None,
        voice_url: str = None,
    ):
        self.voice_id = voice_id
        self.voice_language = voice_language
        self.voice_url = voice_url

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.voice_id is not None:
            result['voiceId'] = self.voice_id

        if self.voice_language is not None:
            result['voiceLanguage'] = self.voice_language

        if self.voice_url is not None:
            result['voiceUrl'] = self.voice_url

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('voiceId') is not None:
            self.voice_id = m.get('voiceId')

        if m.get('voiceLanguage') is not None:
            self.voice_language = m.get('voiceLanguage')

        if m.get('voiceUrl') is not None:
            self.voice_url = m.get('voiceUrl')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class CreateRealisticPortraitRequest(DaraModel):
    def __init__(
        self,
        ages: List[int] = None,
        cloth: int = None,
        color: int = None,
        custom: str = None,
        face: List[int] = None,
        figure: int = None,
        gender: int = None,
        hair_color: int = None,
        hairstyle: int = None,
        height: int = None,
        image_url: str = None,
        numbers: int = None,
        ratio: str = None,
        width: int = None,
    ):
        self.ages = ages
        self.cloth = cloth
        self.color = color
        self.custom = custom
        self.face = face
        self.figure = figure
        self.gender = gender
        self.hair_color = hair_color
        self.hairstyle = hairstyle
        self.height = height
        self.image_url = image_url
        self.numbers = numbers
        self.ratio = ratio
        self.width = width

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.ages is not None:
            result['ages'] = self.ages

        if self.cloth is not None:
            result['cloth'] = self.cloth

        if self.color is not None:
            result['color'] = self.color

        if self.custom is not None:
            result['custom'] = self.custom

        if self.face is not None:
            result['face'] = self.face

        if self.figure is not None:
            result['figure'] = self.figure

        if self.gender is not None:
            result['gender'] = self.gender

        if self.hair_color is not None:
            result['hairColor'] = self.hair_color

        if self.hairstyle is not None:
            result['hairstyle'] = self.hairstyle

        if self.height is not None:
            result['height'] = self.height

        if self.image_url is not None:
            result['imageUrl'] = self.image_url

        if self.numbers is not None:
            result['numbers'] = self.numbers

        if self.ratio is not None:
            result['ratio'] = self.ratio

        if self.width is not None:
            result['width'] = self.width

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ages') is not None:
            self.ages = m.get('ages')

        if m.get('cloth') is not None:
            self.cloth = m.get('cloth')

        if m.get('color') is not None:
            self.color = m.get('color')

        if m.get('custom') is not None:
            self.custom = m.get('custom')

        if m.get('face') is not None:
            self.face = m.get('face')

        if m.get('figure') is not None:
            self.figure = m.get('figure')

        if m.get('gender') is not None:
            self.gender = m.get('gender')

        if m.get('hairColor') is not None:
            self.hair_color = m.get('hairColor')

        if m.get('hairstyle') is not None:
            self.hairstyle = m.get('hairstyle')

        if m.get('height') is not None:
            self.height = m.get('height')

        if m.get('imageUrl') is not None:
            self.image_url = m.get('imageUrl')

        if m.get('numbers') is not None:
            self.numbers = m.get('numbers')

        if m.get('ratio') is not None:
            self.ratio = m.get('ratio')

        if m.get('width') is not None:
            self.width = m.get('width')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ListTextsRequest(DaraModel):
    def __init__(
        self,
        generation_source: str = None,
        industry: str = None,
        keyword: str = None,
        page_number: int = None,
        page_size: int = None,
        publish_status: str = None,
        text_style_type: str = None,
        text_theme: str = None,
    ):
        self.generation_source = generation_source
        self.industry = industry
        self.keyword = keyword
        self.page_number = page_number
        self.page_size = page_size
        self.publish_status = publish_status
        self.text_style_type = text_style_type
        self.text_theme = text_theme

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.generation_source is not None:
            result['generationSource'] = self.generation_source

        if self.industry is not None:
            result['industry'] = self.industry

        if self.keyword is not None:
            result['keyword'] = self.keyword

        if self.page_number is not None:
            result['pageNumber'] = self.page_number

        if self.page_size is not None:
            result['pageSize'] = self.page_size

        if self.publish_status is not None:
            result['publishStatus'] = self.publish_status

        if self.text_style_type is not None:
            result['textStyleType'] = self.text_style_type

        if self.text_theme is not None:
            result['textTheme'] = self.text_theme

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('generationSource') is not None:
            self.generation_source = m.get('generationSource')

        if m.get('industry') is not None:
            self.industry = m.get('industry')

        if m.get('keyword') is not None:
            self.keyword = m.get('keyword')

        if m.get('pageNumber') is not None:
            self.page_number = m.get('pageNumber')

        if m.get('pageSize') is not None:
            self.page_size = m.get('pageSize')

        if m.get('publishStatus') is not None:
            self.publish_status = m.get('publishStatus')

        if m.get('textStyleType') is not None:
            self.text_style_type = m.get('textStyleType')

        if m.get('textTheme') is not None:
            self.text_theme = m.get('textTheme')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class CreateRealisticPortraitResponseBody(DaraModel):
    def __init__(
        self,
        request_id: str = None,
        task_id: str = None,
    ):
        # Id of the request
        self.request_id = request_id
        self.task_id = task_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.task_id is not None:
            result['taskId'] = self.task_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('taskId') is not None:
            self.task_id = m.get('taskId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ListKnowledgeBaseRequest(DaraModel):
    def __init__(
        self,
        knowledge_base_id: str = None,
        page_number: int = None,
        page_size: int = None,
    ):
        self.knowledge_base_id = knowledge_base_id
        self.page_number = page_number
        self.page_size = page_size

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.knowledge_base_id is not None:
            result['knowledgeBaseId'] = self.knowledge_base_id

        if self.page_number is not None:
            result['pageNumber'] = self.page_number

        if self.page_size is not None:
            result['pageSize'] = self.page_size

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('knowledgeBaseId') is not None:
            self.knowledge_base_id = m.get('knowledgeBaseId')

        if m.get('pageNumber') is not None:
            self.page_number = m.get('pageNumber')

        if m.get('pageSize') is not None:
            self.page_size = m.get('pageSize')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class TextTaskResult(DaraModel):
    def __init__(
        self,
        text_task: main_models.TextTask = None,
    ):
        self.text_task = text_task

    def validate(self):
        if self.text_task:
            self.text_task.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.text_task is not None:
            result['textTask'] = self.text_task.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('textTask') is not None:
            temp_model = main_models.TextTask()
            self.text_task = temp_model.from_map(m.get('textTask'))

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class BatchAddDocumentResult(DaraModel):
    def __init__(
        self,
        add_document_results: List[main_models.AddDocumentResult] = None,
        request_id: str = None,
    ):
        # This parameter is required.
        self.add_document_results = add_document_results
        self.request_id = request_id

    def validate(self):
        if self.add_document_results:
            for v1 in self.add_document_results:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['addDocumentResults'] = []
        if self.add_document_results is not None:
            for k1 in self.add_document_results:
                result['addDocumentResults'].append(k1.to_map() if k1 else None)

        if self.request_id is not None:
            result['requestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.add_document_results = []
        if m.get('addDocumentResults') is not None:
            for k1 in m.get('addDocumentResults'):
                temp_model = main_models.AddDocumentResult()
                self.add_document_results.append(temp_model.from_map(k1))

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class QueryTextStreamResponseBody(DaraModel):
    def __init__(
        self,
        end: bool = None,
        index: int = None,
        message: str = None,
        type: int = None,
    ):
        self.end = end
        self.index = index
        # Id of the request
        self.message = message
        self.type = type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.end is not None:
            result['end'] = self.end

        if self.index is not None:
            result['index'] = self.index

        if self.message is not None:
            result['message'] = self.message

        if self.type is not None:
            result['type'] = self.type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('end') is not None:
            self.end = m.get('end')

        if m.get('index') is not None:
            self.index = m.get('index')

        if m.get('message') is not None:
            self.message = m.get('message')

        if m.get('type') is not None:
            self.type = m.get('type')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class ListAgentsRequest(DaraModel):
    def __init__(
        self,
        agent_id: str = None,
        agent_scene: str = None,
        owner: str = None,
        page_number: int = None,
        page_size: int = None,
        status: int = None,
    ):
        self.agent_id = agent_id
        self.agent_scene = agent_scene
        self.owner = owner
        self.page_number = page_number
        self.page_size = page_size
        self.status = status

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.agent_id is not None:
            result['agentId'] = self.agent_id

        if self.agent_scene is not None:
            result['agentScene'] = self.agent_scene

        if self.owner is not None:
            result['owner'] = self.owner

        if self.page_number is not None:
            result['pageNumber'] = self.page_number

        if self.page_size is not None:
            result['pageSize'] = self.page_size

        if self.status is not None:
            result['status'] = self.status

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('agentId') is not None:
            self.agent_id = m.get('agentId')

        if m.get('agentScene') is not None:
            self.agent_scene = m.get('agentScene')

        if m.get('owner') is not None:
            self.owner = m.get('owner')

        if m.get('pageNumber') is not None:
            self.page_number = m.get('pageNumber')

        if m.get('pageSize') is not None:
            self.page_size = m.get('pageSize')

        if m.get('status') is not None:
            self.status = m.get('status')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class BatchAddDocumentRequest(DaraModel):
    def __init__(
        self,
        add_document_infos: List[main_models.AddDocumentInfo] = None,
    ):
        self.add_document_infos = add_document_infos

    def validate(self):
        if self.add_document_infos:
            for v1 in self.add_document_infos:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['addDocumentInfos'] = []
        if self.add_document_infos is not None:
            for k1 in self.add_document_infos:
                result['addDocumentInfos'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.add_document_infos = []
        if m.get('addDocumentInfos') is not None:
            for k1 in m.get('addDocumentInfos'):
                temp_model = main_models.AddDocumentInfo()
                self.add_document_infos.append(temp_model.from_map(k1))

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetAICoachTaskSessionReportResponseBody(DaraModel):
    def __init__(
        self,
        duration: int = None,
        end_time: str = None,
        evaluation_rating: str = None,
        evaluation_result: str = None,
        feedback: bool = None,
        request_id: str = None,
        script_name: str = None,
        start_time: str = None,
        status: str = None,
        uid: str = None,
    ):
        self.duration = duration
        self.end_time = end_time
        self.evaluation_rating = evaluation_rating
        self.evaluation_result = evaluation_result
        self.feedback = feedback
        self.request_id = request_id
        self.script_name = script_name
        self.start_time = start_time
        self.status = status
        self.uid = uid

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.duration is not None:
            result['duration'] = self.duration

        if self.end_time is not None:
            result['endTime'] = self.end_time

        if self.evaluation_rating is not None:
            result['evaluationRating'] = self.evaluation_rating

        if self.evaluation_result is not None:
            result['evaluationResult'] = self.evaluation_result

        if self.feedback is not None:
            result['feedback'] = self.feedback

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.script_name is not None:
            result['scriptName'] = self.script_name

        if self.start_time is not None:
            result['startTime'] = self.start_time

        if self.status is not None:
            result['status'] = self.status

        if self.uid is not None:
            result['uid'] = self.uid

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('duration') is not None:
            self.duration = m.get('duration')

        if m.get('endTime') is not None:
            self.end_time = m.get('endTime')

        if m.get('evaluationRating') is not None:
            self.evaluation_rating = m.get('evaluationRating')

        if m.get('evaluationResult') is not None:
            self.evaluation_result = m.get('evaluationResult')

        if m.get('feedback') is not None:
            self.feedback = m.get('feedback')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('scriptName') is not None:
            self.script_name = m.get('scriptName')

        if m.get('startTime') is not None:
            self.start_time = m.get('startTime')

        if m.get('status') is not None:
            self.status = m.get('status')

        if m.get('uid') is not None:
            self.uid = m.get('uid')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class CreateProductImageRequest(DaraModel):
    def __init__(
        self,
        background_description: str = None,
        background_priority: int = None,
        background_url: str = None,
        highlight_text: str = None,
        image_count: int = None,
        image_url: str = None,
        sub_title: str = None,
        title: str = None,
    ):
        self.background_description = background_description
        self.background_priority = background_priority
        self.background_url = background_url
        self.highlight_text = highlight_text
        self.image_count = image_count
        self.image_url = image_url
        self.sub_title = sub_title
        self.title = title

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.background_description is not None:
            result['backgroundDescription'] = self.background_description

        if self.background_priority is not None:
            result['backgroundPriority'] = self.background_priority

        if self.background_url is not None:
            result['backgroundUrl'] = self.background_url

        if self.highlight_text is not None:
            result['highlightText'] = self.highlight_text

        if self.image_count is not None:
            result['imageCount'] = self.image_count

        if self.image_url is not None:
            result['imageUrl'] = self.image_url

        if self.sub_title is not None:
            result['subTitle'] = self.sub_title

        if self.title is not None:
            result['title'] = self.title

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('backgroundDescription') is not None:
            self.background_description = m.get('backgroundDescription')

        if m.get('backgroundPriority') is not None:
            self.background_priority = m.get('backgroundPriority')

        if m.get('backgroundUrl') is not None:
            self.background_url = m.get('backgroundUrl')

        if m.get('highlightText') is not None:
            self.highlight_text = m.get('highlightText')

        if m.get('imageCount') is not None:
            self.image_count = m.get('imageCount')

        if m.get('imageUrl') is not None:
            self.image_url = m.get('imageUrl')

        if m.get('subTitle') is not None:
            self.sub_title = m.get('subTitle')

        if m.get('title') is not None:
            self.title = m.get('title')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class VoiceModelResponse(DaraModel):
    def __init__(
        self,
        resource_type_desc: str = None,
        tts_version: int = None,
        use_scene: str = None,
        voice_desc: str = None,
        voice_gender: str = None,
        voice_id: int = None,
        voice_language: str = None,
        voice_model: str = None,
        voice_name: str = None,
        voice_type: str = None,
        voice_url: str = None,
    ):
        self.resource_type_desc = resource_type_desc
        self.tts_version = tts_version
        self.use_scene = use_scene
        self.voice_desc = voice_desc
        self.voice_gender = voice_gender
        self.voice_id = voice_id
        self.voice_language = voice_language
        self.voice_model = voice_model
        self.voice_name = voice_name
        self.voice_type = voice_type
        self.voice_url = voice_url

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.resource_type_desc is not None:
            result['resourceTypeDesc'] = self.resource_type_desc

        if self.tts_version is not None:
            result['ttsVersion'] = self.tts_version

        if self.use_scene is not None:
            result['useScene'] = self.use_scene

        if self.voice_desc is not None:
            result['voiceDesc'] = self.voice_desc

        if self.voice_gender is not None:
            result['voiceGender'] = self.voice_gender

        if self.voice_id is not None:
            result['voiceId'] = self.voice_id

        if self.voice_language is not None:
            result['voiceLanguage'] = self.voice_language

        if self.voice_model is not None:
            result['voiceModel'] = self.voice_model

        if self.voice_name is not None:
            result['voiceName'] = self.voice_name

        if self.voice_type is not None:
            result['voiceType'] = self.voice_type

        if self.voice_url is not None:
            result['voiceUrl'] = self.voice_url

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('resourceTypeDesc') is not None:
            self.resource_type_desc = m.get('resourceTypeDesc')

        if m.get('ttsVersion') is not None:
            self.tts_version = m.get('ttsVersion')

        if m.get('useScene') is not None:
            self.use_scene = m.get('useScene')

        if m.get('voiceDesc') is not None:
            self.voice_desc = m.get('voiceDesc')

        if m.get('voiceGender') is not None:
            self.voice_gender = m.get('voiceGender')

        if m.get('voiceId') is not None:
            self.voice_id = m.get('voiceId')

        if m.get('voiceLanguage') is not None:
            self.voice_language = m.get('voiceLanguage')

        if m.get('voiceModel') is not None:
            self.voice_model = m.get('voiceModel')

        if m.get('voiceName') is not None:
            self.voice_name = m.get('voiceName')

        if m.get('voiceType') is not None:
            self.voice_type = m.get('voiceType')

        if m.get('voiceUrl') is not None:
            self.voice_url = m.get('voiceUrl')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class Illustration(DaraModel):
    def __init__(
        self,
        illustration_id: int = None,
        oss: str = None,
    ):
        self.illustration_id = illustration_id
        self.oss = oss

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.illustration_id is not None:
            result['illustrationId'] = self.illustration_id

        if self.oss is not None:
            result['oss'] = self.oss

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('illustrationId') is not None:
            self.illustration_id = m.get('illustrationId')

        if m.get('oss') is not None:
            self.oss = m.get('oss')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class StartAvatarSessionResponseBody(DaraModel):
    def __init__(
        self,
        channel_token: str = None,
        request_id: str = None,
        session_id: str = None,
        token: str = None,
        web_socket_url: str = None,
    ):
        self.channel_token = channel_token
        self.request_id = request_id
        self.session_id = session_id
        self.token = token
        self.web_socket_url = web_socket_url

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.channel_token is not None:
            result['channelToken'] = self.channel_token

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.session_id is not None:
            result['sessionId'] = self.session_id

        if self.token is not None:
            result['token'] = self.token

        if self.web_socket_url is not None:
            result['webSocketUrl'] = self.web_socket_url

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('channelToken') is not None:
            self.channel_token = m.get('channelToken')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('sessionId') is not None:
            self.session_id = m.get('sessionId')

        if m.get('token') is not None:
            self.token = m.get('token')

        if m.get('webSocketUrl') is not None:
            self.web_socket_url = m.get('webSocketUrl')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class CreateAgentRequest(DaraModel):
    def __init__(
        self,
        agent_icon_url: str = None,
        agent_name: str = None,
        agent_scene: str = None,
        character_age_stage: str = None,
        character_gender: str = None,
        character_name: str = None,
        extra_description: str = None,
        industry: str = None,
    ):
        self.agent_icon_url = agent_icon_url
        self.agent_name = agent_name
        self.agent_scene = agent_scene
        self.character_age_stage = character_age_stage
        self.character_gender = character_gender
        self.character_name = character_name
        self.extra_description = extra_description
        self.industry = industry

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.agent_icon_url is not None:
            result['agentIconUrl'] = self.agent_icon_url

        if self.agent_name is not None:
            result['agentName'] = self.agent_name

        if self.agent_scene is not None:
            result['agentScene'] = self.agent_scene

        if self.character_age_stage is not None:
            result['characterAgeStage'] = self.character_age_stage

        if self.character_gender is not None:
            result['characterGender'] = self.character_gender

        if self.character_name is not None:
            result['characterName'] = self.character_name

        if self.extra_description is not None:
            result['extraDescription'] = self.extra_description

        if self.industry is not None:
            result['industry'] = self.industry

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('agentIconUrl') is not None:
            self.agent_icon_url = m.get('agentIconUrl')

        if m.get('agentName') is not None:
            self.agent_name = m.get('agentName')

        if m.get('agentScene') is not None:
            self.agent_scene = m.get('agentScene')

        if m.get('characterAgeStage') is not None:
            self.character_age_stage = m.get('characterAgeStage')

        if m.get('characterGender') is not None:
            self.character_gender = m.get('characterGender')

        if m.get('characterName') is not None:
            self.character_name = m.get('characterName')

        if m.get('extraDescription') is not None:
            self.extra_description = m.get('extraDescription')

        if m.get('industry') is not None:
            self.industry = m.get('industry')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from ._add_document_info import AddDocumentInfo
from ._add_document_result import AddDocumentResult
from ._anchor_response import AnchorResponse
from ._batch_add_document_result import BatchAddDocumentResult
from ._document_info import DocumentInfo
from ._document_result import DocumentResult
from ._get_oss_upload_token_result import GetOssUploadTokenResult
from ._illustration import Illustration
from ._illustration_result import IllustrationResult
from ._illustration_task import IllustrationTask
from ._illustration_task_create_cmd import IllustrationTaskCreateCmd
from ._illustration_task_result import IllustrationTaskResult
from ._knowledge_base_info import KnowledgeBaseInfo
from ._knowledge_base_list_result import KnowledgeBaseListResult
from ._reference_tag import ReferenceTag
from ._text import Text
from ._text_query_result import TextQueryResult
from ._text_result import TextResult
from ._text_task import TextTask
from ._text_task_create_cmd import TextTaskCreateCmd
from ._text_task_result import TextTaskResult
from ._text_theme import TextTheme
from ._text_theme_list_result import TextThemeListResult
from ._upload_info import UploadInfo
from ._voice_model_response import VoiceModelResponse
from ._add_text_feedback_request import AddTextFeedbackRequest
from ._add_text_feedback_response_body import AddTextFeedbackResponseBody
from ._add_text_feedback_response import AddTextFeedbackResponse
from ._batch_add_document_request import BatchAddDocumentRequest
from ._batch_add_document_response import BatchAddDocumentResponse
from ._batch_create_aicoach_task_request import BatchCreateAICoachTaskRequest
from ._batch_create_aicoach_task_response_body import BatchCreateAICoachTaskResponseBody
from ._batch_create_aicoach_task_response import BatchCreateAICoachTaskResponse
from ._batch_get_project_task_request import BatchGetProjectTaskRequest
from ._batch_get_project_task_shrink_request import BatchGetProjectTaskShrinkRequest
from ._batch_get_project_task_response_body import BatchGetProjectTaskResponseBody
from ._batch_get_project_task_response import BatchGetProjectTaskResponse
from ._batch_get_train_task_request import BatchGetTrainTaskRequest
from ._batch_get_train_task_shrink_request import BatchGetTrainTaskShrinkRequest
from ._batch_get_train_task_response_body import BatchGetTrainTaskResponseBody
from ._batch_get_train_task_response import BatchGetTrainTaskResponse
from ._batch_get_video_clip_task_request import BatchGetVideoClipTaskRequest
from ._batch_get_video_clip_task_shrink_request import BatchGetVideoClipTaskShrinkRequest
from ._batch_get_video_clip_task_response_body import BatchGetVideoClipTaskResponseBody
from ._batch_get_video_clip_task_response import BatchGetVideoClipTaskResponse
from ._batch_query_individuation_text_request import BatchQueryIndividuationTextRequest
from ._batch_query_individuation_text_shrink_request import BatchQueryIndividuationTextShrinkRequest
from ._batch_query_individuation_text_response_body import BatchQueryIndividuationTextResponseBody
from ._batch_query_individuation_text_response import BatchQueryIndividuationTextResponse
from ._build_aicoach_script_record_request import BuildAICoachScriptRecordRequest
from ._build_aicoach_script_record_response_body import BuildAICoachScriptRecordResponseBody
from ._build_aicoach_script_record_response import BuildAICoachScriptRecordResponse
from ._check_session_request import CheckSessionRequest
from ._check_session_response_body import CheckSessionResponseBody
from ._check_session_response import CheckSessionResponse
from ._close_aicoach_task_session_request import CloseAICoachTaskSessionRequest
from ._close_aicoach_task_session_response_body import CloseAICoachTaskSessionResponseBody
from ._close_aicoach_task_session_response import CloseAICoachTaskSessionResponse
from ._count_text_request import CountTextRequest
from ._count_text_response_body import CountTextResponseBody
from ._count_text_response import CountTextResponse
from ._create_aicoach_task_request import CreateAICoachTaskRequest
from ._create_aicoach_task_response_body import CreateAICoachTaskResponseBody
from ._create_aicoach_task_response import CreateAICoachTaskResponse
from ._create_aicoach_task_session_request import CreateAICoachTaskSessionRequest
from ._create_aicoach_task_session_response_body import CreateAICoachTaskSessionResponseBody
from ._create_aicoach_task_session_response import CreateAICoachTaskSessionResponse
from ._create_agent_request import CreateAgentRequest
from ._create_agent_response_body import CreateAgentResponseBody
from ._create_agent_response import CreateAgentResponse
from ._create_anchor_request import CreateAnchorRequest
from ._create_anchor_response_body import CreateAnchorResponseBody
from ._create_anchor_response import CreateAnchorResponse
from ._create_illustration_task_request import CreateIllustrationTaskRequest
from ._create_illustration_task_response import CreateIllustrationTaskResponse
from ._create_individuation_project_request import CreateIndividuationProjectRequest
from ._create_individuation_project_response_body import CreateIndividuationProjectResponseBody
from ._create_individuation_project_response import CreateIndividuationProjectResponse
from ._create_individuation_text_task_request import CreateIndividuationTextTaskRequest
from ._create_individuation_text_task_response_body import CreateIndividuationTextTaskResponseBody
from ._create_individuation_text_task_response import CreateIndividuationTextTaskResponse
from ._create_product_image_request import CreateProductImageRequest
from ._create_product_image_response_body import CreateProductImageResponseBody
from ._create_product_image_response import CreateProductImageResponse
from ._create_realistic_portrait_request import CreateRealisticPortraitRequest
from ._create_realistic_portrait_response_body import CreateRealisticPortraitResponseBody
from ._create_realistic_portrait_response import CreateRealisticPortraitResponse
from ._create_text_task_request import CreateTextTaskRequest
from ._create_text_task_response import CreateTextTaskResponse
from ._create_train_task_request import CreateTrainTaskRequest
from ._create_train_task_response_body import CreateTrainTaskResponseBody
from ._create_train_task_response import CreateTrainTaskResponse
from ._create_video_clip_task_request import CreateVideoClipTaskRequest
from ._create_video_clip_task_response_body import CreateVideoClipTaskResponseBody
from ._create_video_clip_task_response import CreateVideoClipTaskResponse
from ._delete_aicoach_script_request import DeleteAICoachScriptRequest
from ._delete_aicoach_script_response_body import DeleteAICoachScriptResponseBody
from ._delete_aicoach_script_response import DeleteAICoachScriptResponse
from ._delete_agent_request import DeleteAgentRequest
from ._delete_agent_response_body import DeleteAgentResponseBody
from ._delete_agent_response import DeleteAgentResponse
from ._delete_individuation_project_request import DeleteIndividuationProjectRequest
from ._delete_individuation_project_response_body import DeleteIndividuationProjectResponseBody
from ._delete_individuation_project_response import DeleteIndividuationProjectResponse
from ._delete_individuation_text_request import DeleteIndividuationTextRequest
from ._delete_individuation_text_response_body import DeleteIndividuationTextResponseBody
from ._delete_individuation_text_response import DeleteIndividuationTextResponse
from ._describe_document_response import DescribeDocumentResponse
from ._finish_aicoach_task_session_request import FinishAICoachTaskSessionRequest
from ._finish_aicoach_task_session_response_body import FinishAICoachTaskSessionResponseBody
from ._finish_aicoach_task_session_response import FinishAICoachTaskSessionResponse
from ._get_aicoach_assessment_point_request import GetAICoachAssessmentPointRequest
from ._get_aicoach_assessment_point_response_body import GetAICoachAssessmentPointResponseBody
from ._get_aicoach_assessment_point_response import GetAICoachAssessmentPointResponse
from ._get_aicoach_cheat_detection_request import GetAICoachCheatDetectionRequest
from ._get_aicoach_cheat_detection_response_body import GetAICoachCheatDetectionResponseBody
from ._get_aicoach_cheat_detection_response import GetAICoachCheatDetectionResponse
from ._get_aicoach_script_request import GetAICoachScriptRequest
from ._get_aicoach_script_response_body import GetAICoachScriptResponseBody
from ._get_aicoach_script_response import GetAICoachScriptResponse
from ._get_aicoach_task_session_history_request import GetAICoachTaskSessionHistoryRequest
from ._get_aicoach_task_session_history_response_body import GetAICoachTaskSessionHistoryResponseBody
from ._get_aicoach_task_session_history_response import GetAICoachTaskSessionHistoryResponse
from ._get_aicoach_task_session_report_request import GetAICoachTaskSessionReportRequest
from ._get_aicoach_task_session_report_response_body import GetAICoachTaskSessionReportResponseBody
from ._get_aicoach_task_session_report_response import GetAICoachTaskSessionReportResponse
from ._get_aicoach_task_session_resource_usage_request import GetAICoachTaskSessionResourceUsageRequest
from ._get_aicoach_task_session_resource_usage_response_body import GetAICoachTaskSessionResourceUsageResponseBody
from ._get_aicoach_task_session_resource_usage_response import GetAICoachTaskSessionResourceUsageResponse
from ._get_illustration_response import GetIllustrationResponse
from ._get_illustration_task_response import GetIllustrationTaskResponse
from ._get_oss_upload_token_request import GetOssUploadTokenRequest
from ._get_oss_upload_token_response import GetOssUploadTokenResponse
from ._get_project_task_request import GetProjectTaskRequest
from ._get_project_task_response_body import GetProjectTaskResponseBody
from ._get_project_task_response import GetProjectTaskResponse
from ._get_text_response import GetTextResponse
from ._get_text_task_response import GetTextTaskResponse
from ._get_text_template_request import GetTextTemplateRequest
from ._get_text_template_response_body import GetTextTemplateResponseBody
from ._get_text_template_response import GetTextTemplateResponse
from ._interact_text_request import InteractTextRequest
from ._interact_text_response_body import InteractTextResponseBody
from ._interact_text_response import InteractTextResponse
from ._list_aicoach_script_page_request import ListAICoachScriptPageRequest
from ._list_aicoach_script_page_response_body import ListAICoachScriptPageResponseBody
from ._list_aicoach_script_page_response import ListAICoachScriptPageResponse
from ._list_aicoach_task_page_request import ListAICoachTaskPageRequest
from ._list_aicoach_task_page_response_body import ListAICoachTaskPageResponseBody
from ._list_aicoach_task_page_response import ListAICoachTaskPageResponse
from ._list_agents_request import ListAgentsRequest
from ._list_agents_response_body import ListAgentsResponseBody
from ._list_agents_response import ListAgentsResponse
from ._list_anchor_request import ListAnchorRequest
from ._list_anchor_response_body import ListAnchorResponseBody
from ._list_anchor_response import ListAnchorResponse
from ._list_avatar_project_request import ListAvatarProjectRequest
from ._list_avatar_project_shrink_request import ListAvatarProjectShrinkRequest
from ._list_avatar_project_response_body import ListAvatarProjectResponseBody
from ._list_avatar_project_response import ListAvatarProjectResponse
from ._list_knowledge_base_request import ListKnowledgeBaseRequest
from ._list_knowledge_base_response import ListKnowledgeBaseResponse
from ._list_text_themes_request import ListTextThemesRequest
from ._list_text_themes_response import ListTextThemesResponse
from ._list_texts_request import ListTextsRequest
from ._list_texts_response import ListTextsResponse
from ._list_voice_models_request import ListVoiceModelsRequest
from ._list_voice_models_response_body import ListVoiceModelsResponseBody
from ._list_voice_models_response import ListVoiceModelsResponse
from ._offline_aicoach_script_request import OfflineAICoachScriptRequest
from ._offline_aicoach_script_response_body import OfflineAICoachScriptResponseBody
from ._offline_aicoach_script_response import OfflineAICoachScriptResponse
from ._operate_avatar_project_request import OperateAvatarProjectRequest
from ._operate_avatar_project_response_body import OperateAvatarProjectResponseBody
from ._operate_avatar_project_response import OperateAvatarProjectResponse
from ._query_avatar_project_request import QueryAvatarProjectRequest
from ._query_avatar_project_response_body import QueryAvatarProjectResponseBody
from ._query_avatar_project_response import QueryAvatarProjectResponse
from ._query_avatar_resource_request import QueryAvatarResourceRequest
from ._query_avatar_resource_response_body import QueryAvatarResourceResponseBody
from ._query_avatar_resource_response import QueryAvatarResourceResponse
from ._query_image_to_video_task_request import QueryImageToVideoTaskRequest
from ._query_image_to_video_task_response_body import QueryImageToVideoTaskResponseBody
from ._query_image_to_video_task_response import QueryImageToVideoTaskResponse
from ._query_individuation_text_task_request import QueryIndividuationTextTaskRequest
from ._query_individuation_text_task_response_body import QueryIndividuationTextTaskResponseBody
from ._query_individuation_text_task_response import QueryIndividuationTextTaskResponse
from ._query_session_info_request import QuerySessionInfoRequest
from ._query_session_info_shrink_request import QuerySessionInfoShrinkRequest
from ._query_session_info_response_body import QuerySessionInfoResponseBody
from ._query_session_info_response import QuerySessionInfoResponse
from ._query_text_stream_response_body import QueryTextStreamResponseBody
from ._query_text_stream_response import QueryTextStreamResponse
from ._release_agent_request import ReleaseAgentRequest
from ._release_agent_response_body import ReleaseAgentResponseBody
from ._release_agent_response import ReleaseAgentResponse
from ._save_avatar_project_request import SaveAvatarProjectRequest
from ._save_avatar_project_response_body import SaveAvatarProjectResponseBody
from ._save_avatar_project_response import SaveAvatarProjectResponse
from ._select_image_task_response_body import SelectImageTaskResponseBody
from ._select_image_task_response import SelectImageTaskResponse
from ._select_resource_request import SelectResourceRequest
from ._select_resource_response_body import SelectResourceResponseBody
from ._select_resource_response import SelectResourceResponse
from ._send_sdk_message_request import SendSdkMessageRequest
from ._send_sdk_message_response_body import SendSdkMessageResponseBody
from ._send_sdk_message_response import SendSdkMessageResponse
from ._send_sdk_stream_message_request import SendSdkStreamMessageRequest
from ._send_sdk_stream_message_response_body import SendSdkStreamMessageResponseBody
from ._send_sdk_stream_message_response import SendSdkStreamMessageResponse
from ._send_text_msg_request import SendTextMsgRequest
from ._send_text_msg_response_body import SendTextMsgResponseBody
from ._send_text_msg_response import SendTextMsgResponse
from ._start_avatar_session_request import StartAvatarSessionRequest
from ._start_avatar_session_response_body import StartAvatarSessionResponseBody
from ._start_avatar_session_response import StartAvatarSessionResponse
from ._stop_avatar_session_request import StopAvatarSessionRequest
from ._stop_avatar_session_response_body import StopAvatarSessionResponseBody
from ._stop_avatar_session_response import StopAvatarSessionResponse
from ._stop_project_task_request import StopProjectTaskRequest
from ._stop_project_task_response_body import StopProjectTaskResponseBody
from ._stop_project_task_response import StopProjectTaskResponse
from ._submit_image_to_video_task_request import SubmitImageToVideoTaskRequest
from ._submit_image_to_video_task_response_body import SubmitImageToVideoTaskResponseBody
from ._submit_image_to_video_task_response import SubmitImageToVideoTaskResponse
from ._submit_project_task_request import SubmitProjectTaskRequest
from ._submit_project_task_response_body import SubmitProjectTaskResponseBody
from ._submit_project_task_response import SubmitProjectTaskResponse
from ._transfer_portrait_style_request import TransferPortraitStyleRequest
from ._transfer_portrait_style_response_body import TransferPortraitStyleResponseBody
from ._transfer_portrait_style_response import TransferPortraitStyleResponse
from ._update_agent_request import UpdateAgentRequest
from ._update_agent_response_body import UpdateAgentResponseBody
from ._update_agent_response import UpdateAgentResponse
from ._batch_create_aicoach_task_request import BatchCreateAICoachTaskRequestStudentList
from ._batch_get_project_task_response_body import BatchGetProjectTaskResponseBodyResultList
from ._batch_get_train_task_response_body import BatchGetTrainTaskResponseBodyVoiceListVoiceMaterial
from ._batch_get_train_task_response_body import BatchGetTrainTaskResponseBodyVoiceList
from ._batch_get_video_clip_task_response_body import BatchGetVideoClipTaskResponseBodyTaskListVideoList
from ._batch_get_video_clip_task_response_body import BatchGetVideoClipTaskResponseBodyTaskList
from ._batch_query_individuation_text_response_body import BatchQueryIndividuationTextResponseBodyTextList
from ._build_aicoach_script_record_response_body import BuildAICoachScriptRecordResponseBodyData
from ._count_text_response_body import CountTextResponseBodyCountTextCmdList
from ._create_aicoach_task_session_response_body import CreateAICoachTaskSessionResponseBodyScriptInfo
from ._get_aicoach_assessment_point_response_body import GetAICoachAssessmentPointResponseBodyAnswerListAnswerValuesKeywordValues
from ._get_aicoach_assessment_point_response_body import GetAICoachAssessmentPointResponseBodyAnswerListAnswerValuesScoringRules
from ._get_aicoach_assessment_point_response_body import GetAICoachAssessmentPointResponseBodyAnswerListAnswerValues
from ._get_aicoach_assessment_point_response_body import GetAICoachAssessmentPointResponseBodyAnswerListParameters
from ._get_aicoach_assessment_point_response_body import GetAICoachAssessmentPointResponseBodyAnswerList
from ._get_aicoach_cheat_detection_response_body import GetAICoachCheatDetectionResponseBodyImageCheatList
from ._get_aicoach_cheat_detection_response_body import GetAICoachCheatDetectionResponseBodyImageCheat
from ._get_aicoach_cheat_detection_response_body import GetAICoachCheatDetectionResponseBodyVoiceCheatComparisonList
from ._get_aicoach_cheat_detection_response_body import GetAICoachCheatDetectionResponseBodyVoiceCheatOriginalList
from ._get_aicoach_cheat_detection_response_body import GetAICoachCheatDetectionResponseBodyVoiceCheat
from ._get_aicoach_script_response_body import GetAICoachScriptResponseBodyCheckCheatConfig
from ._get_aicoach_script_response_body import GetAICoachScriptResponseBodyCompleteStrategy
from ._get_aicoach_script_response_body import GetAICoachScriptResponseBodyCustomReplyRulesActionParameters
from ._get_aicoach_script_response_body import GetAICoachScriptResponseBodyCustomReplyRulesAction
from ._get_aicoach_script_response_body import GetAICoachScriptResponseBodyCustomReplyRulesMainConditionParameters
from ._get_aicoach_script_response_body import GetAICoachScriptResponseBodyCustomReplyRulesMainCondition
from ._get_aicoach_script_response_body import GetAICoachScriptResponseBodyCustomReplyRulesSubCondition
from ._get_aicoach_script_response_body import GetAICoachScriptResponseBodyCustomReplyRules
from ._get_aicoach_script_response_body import GetAICoachScriptResponseBodyExpressivenessList
from ._get_aicoach_script_response_body import GetAICoachScriptResponseBodyPointDeductionRuleList
from ._get_aicoach_script_response_body import GetAICoachScriptResponseBodyPointsAnswerListAnswerValuesKeywordValues
from ._get_aicoach_script_response_body import GetAICoachScriptResponseBodyPointsAnswerListAnswerValuesScoringRules
from ._get_aicoach_script_response_body import GetAICoachScriptResponseBodyPointsAnswerListAnswerValues
from ._get_aicoach_script_response_body import GetAICoachScriptResponseBodyPointsAnswerListParameters
from ._get_aicoach_script_response_body import GetAICoachScriptResponseBodyPointsAnswerList
from ._get_aicoach_script_response_body import GetAICoachScriptResponseBodyPoints
from ._get_aicoach_script_response_body import GetAICoachScriptResponseBodySampleDialogueList
from ._get_aicoach_script_response_body import GetAICoachScriptResponseBodyScoreConfigLevels
from ._get_aicoach_script_response_body import GetAICoachScriptResponseBodyScoreConfig
from ._get_aicoach_script_response_body import GetAICoachScriptResponseBodyWeights
from ._get_aicoach_task_session_history_response_body import GetAICoachTaskSessionHistoryResponseBodyConversationList
from ._get_text_template_response_body import GetTextTemplateResponseBodyAvailableIndustryTextModeTypesTextStyles
from ._get_text_template_response_body import GetTextTemplateResponseBodyAvailableIndustryTextModeTypes
from ._get_text_template_response_body import GetTextTemplateResponseBodyAvailableIndustry
from ._list_aicoach_script_page_response_body import ListAICoachScriptPageResponseBodyListCompleteStrategy
from ._list_aicoach_script_page_response_body import ListAICoachScriptPageResponseBodyListCustomReplyRulesActionParameters
from ._list_aicoach_script_page_response_body import ListAICoachScriptPageResponseBodyListCustomReplyRulesAction
from ._list_aicoach_script_page_response_body import ListAICoachScriptPageResponseBodyListCustomReplyRulesMainConditionParameters
from ._list_aicoach_script_page_response_body import ListAICoachScriptPageResponseBodyListCustomReplyRulesMainCondition
from ._list_aicoach_script_page_response_body import ListAICoachScriptPageResponseBodyListCustomReplyRulesSubCondition
from ._list_aicoach_script_page_response_body import ListAICoachScriptPageResponseBodyListCustomReplyRules
from ._list_aicoach_script_page_response_body import ListAICoachScriptPageResponseBodyListSampleDialogueList
from ._list_aicoach_script_page_response_body import ListAICoachScriptPageResponseBodyListScoreConfigLevels
from ._list_aicoach_script_page_response_body import ListAICoachScriptPageResponseBodyListScoreConfig
from ._list_aicoach_script_page_response_body import ListAICoachScriptPageResponseBodyListWeights
from ._list_aicoach_script_page_response_body import ListAICoachScriptPageResponseBodyList
from ._list_aicoach_task_page_response_body import ListAICoachTaskPageResponseBodyTaskList
from ._list_agents_response_body import ListAgentsResponseBodyList
from ._list_avatar_project_response_body import ListAvatarProjectResponseBodyQueryAvatarProjectResultList
from ._query_avatar_project_response_body import QueryAvatarProjectResponseBodyFramesLayersMaterial
from ._query_avatar_project_response_body import QueryAvatarProjectResponseBodyFramesLayers
from ._query_avatar_project_response_body import QueryAvatarProjectResponseBodyFramesVideoScript
from ._query_avatar_project_response_body import QueryAvatarProjectResponseBodyFrames
from ._query_avatar_resource_response_body import QueryAvatarResourceResponseBodyQueryResourceInfoList
from ._query_individuation_text_task_response_body import QueryIndividuationTextTaskResponseBodyTextList
from ._query_session_info_response_body import QuerySessionInfoResponseBodyQueryResourceInfoList
from ._save_avatar_project_request import SaveAvatarProjectRequestFramesLayersMaterial
from ._save_avatar_project_request import SaveAvatarProjectRequestFramesLayers
from ._save_avatar_project_request import SaveAvatarProjectRequestFramesVideoScript
from ._save_avatar_project_request import SaveAvatarProjectRequestFrames
from ._select_image_task_response_body import SelectImageTaskResponseBodyImageInfos
from ._select_resource_response_body import SelectResourceResponseBodyResourceInfoList
from ._submit_project_task_request import SubmitProjectTaskRequestFramesLayersMaterialMask
from ._submit_project_task_request import SubmitProjectTaskRequestFramesLayersMaterial
from ._submit_project_task_request import SubmitProjectTaskRequestFramesLayers
from ._submit_project_task_request import SubmitProjectTaskRequestFramesSubtitle
from ._submit_project_task_request import SubmitProjectTaskRequestFramesVideoScript
from ._submit_project_task_request import SubmitProjectTaskRequestFrames

__all__ = [
    AddDocumentInfo,
    AddDocumentResult,
    AnchorResponse,
    BatchAddDocumentResult,
    DocumentInfo,
    DocumentResult,
    GetOssUploadTokenResult,
    Illustration,
    IllustrationResult,
    IllustrationTask,
    IllustrationTaskCreateCmd,
    IllustrationTaskResult,
    KnowledgeBaseInfo,
    KnowledgeBaseListResult,
    ReferenceTag,
    Text,
    TextQueryResult,
    TextResult,
    TextTask,
    TextTaskCreateCmd,
    TextTaskResult,
    TextTheme,
    TextThemeListResult,
    UploadInfo,
    VoiceModelResponse,
    AddTextFeedbackRequest,
    AddTextFeedbackResponseBody,
    AddTextFeedbackResponse,
    BatchAddDocumentRequest,
    BatchAddDocumentResponse,
    BatchCreateAICoachTaskRequest,
    BatchCreateAICoachTaskResponseBody,
    BatchCreateAICoachTaskResponse,
    BatchGetProjectTaskRequest,
    BatchGetProjectTaskShrinkRequest,
    BatchGetProjectTaskResponseBody,
    BatchGetProjectTaskResponse,
    BatchGetTrainTaskRequest,
    BatchGetTrainTaskShrinkRequest,
    BatchGetTrainTaskResponseBody,
    BatchGetTrainTaskResponse,
    BatchGetVideoClipTaskRequest,
    BatchGetVideoClipTaskShrinkRequest,
    BatchGetVideoClipTaskResponseBody,
    BatchGetVideoClipTaskResponse,
    BatchQueryIndividuationTextRequest,
    BatchQueryIndividuationTextShrinkRequest,
    BatchQueryIndividuationTextResponseBody,
    BatchQueryIndividuationTextResponse,
    BuildAICoachScriptRecordRequest,
    BuildAICoachScriptRecordResponseBody,
    BuildAICoachScriptRecordResponse,
    CheckSessionRequest,
    CheckSessionResponseBody,
    CheckSessionResponse,
    CloseAICoachTaskSessionRequest,
    CloseAICoachTaskSessionResponseBody,
    CloseAICoachTaskSessionResponse,
    CountTextRequest,
    CountTextResponseBody,
    CountTextResponse,
    CreateAICoachTaskRequest,
    CreateAICoachTaskResponseBody,
    CreateAICoachTaskResponse,
    CreateAICoachTaskSessionRequest,
    CreateAICoachTaskSessionResponseBody,
    CreateAICoachTaskSessionResponse,
    CreateAgentRequest,
    CreateAgentResponseBody,
    CreateAgentResponse,
    CreateAnchorRequest,
    CreateAnchorResponseBody,
    CreateAnchorResponse,
    CreateIllustrationTaskRequest,
    CreateIllustrationTaskResponse,
    CreateIndividuationProjectRequest,
    CreateIndividuationProjectResponseBody,
    CreateIndividuationProjectResponse,
    CreateIndividuationTextTaskRequest,
    CreateIndividuationTextTaskResponseBody,
    CreateIndividuationTextTaskResponse,
    CreateProductImageRequest,
    CreateProductImageResponseBody,
    CreateProductImageResponse,
    CreateRealisticPortraitRequest,
    CreateRealisticPortraitResponseBody,
    CreateRealisticPortraitResponse,
    CreateTextTaskRequest,
    CreateTextTaskResponse,
    CreateTrainTaskRequest,
    CreateTrainTaskResponseBody,
    CreateTrainTaskResponse,
    CreateVideoClipTaskRequest,
    CreateVideoClipTaskResponseBody,
    CreateVideoClipTaskResponse,
    DeleteAICoachScriptRequest,
    DeleteAICoachScriptResponseBody,
    DeleteAICoachScriptResponse,
    DeleteAgentRequest,
    DeleteAgentResponseBody,
    DeleteAgentResponse,
    DeleteIndividuationProjectRequest,
    DeleteIndividuationProjectResponseBody,
    DeleteIndividuationProjectResponse,
    DeleteIndividuationTextRequest,
    DeleteIndividuationTextResponseBody,
    DeleteIndividuationTextResponse,
    DescribeDocumentResponse,
    FinishAICoachTaskSessionRequest,
    FinishAICoachTaskSessionResponseBody,
    FinishAICoachTaskSessionResponse,
    GetAICoachAssessmentPointRequest,
    GetAICoachAssessmentPointResponseBody,
    GetAICoachAssessmentPointResponse,
    GetAICoachCheatDetectionRequest,
    GetAICoachCheatDetectionResponseBody,
    GetAICoachCheatDetectionResponse,
    GetAICoachScriptRequest,
    GetAICoachScriptResponseBody,
    GetAICoachScriptResponse,
    GetAICoachTaskSessionHistoryRequest,
    GetAICoachTaskSessionHistoryResponseBody,
    GetAICoachTaskSessionHistoryResponse,
    GetAICoachTaskSessionReportRequest,
    GetAICoachTaskSessionReportResponseBody,
    GetAICoachTaskSessionReportResponse,
    GetAICoachTaskSessionResourceUsageRequest,
    GetAICoachTaskSessionResourceUsageResponseBody,
    GetAICoachTaskSessionResourceUsageResponse,
    GetIllustrationResponse,
    GetIllustrationTaskResponse,
    GetOssUploadTokenRequest,
    GetOssUploadTokenResponse,
    GetProjectTaskRequest,
    GetProjectTaskResponseBody,
    GetProjectTaskResponse,
    GetTextResponse,
    GetTextTaskResponse,
    GetTextTemplateRequest,
    GetTextTemplateResponseBody,
    GetTextTemplateResponse,
    InteractTextRequest,
    InteractTextResponseBody,
    InteractTextResponse,
    ListAICoachScriptPageRequest,
    ListAICoachScriptPageResponseBody,
    ListAICoachScriptPageResponse,
    ListAICoachTaskPageRequest,
    ListAICoachTaskPageResponseBody,
    ListAICoachTaskPageResponse,
    ListAgentsRequest,
    ListAgentsResponseBody,
    ListAgentsResponse,
    ListAnchorRequest,
    ListAnchorResponseBody,
    ListAnchorResponse,
    ListAvatarProjectRequest,
    ListAvatarProjectShrinkRequest,
    ListAvatarProjectResponseBody,
    ListAvatarProjectResponse,
    ListKnowledgeBaseRequest,
    ListKnowledgeBaseResponse,
    ListTextThemesRequest,
    ListTextThemesResponse,
    ListTextsRequest,
    ListTextsResponse,
    ListVoiceModelsRequest,
    ListVoiceModelsResponseBody,
    ListVoiceModelsResponse,
    OfflineAICoachScriptRequest,
    OfflineAICoachScriptResponseBody,
    OfflineAICoachScriptResponse,
    OperateAvatarProjectRequest,
    OperateAvatarProjectResponseBody,
    OperateAvatarProjectResponse,
    QueryAvatarProjectRequest,
    QueryAvatarProjectResponseBody,
    QueryAvatarProjectResponse,
    QueryAvatarResourceRequest,
    QueryAvatarResourceResponseBody,
    QueryAvatarResourceResponse,
    QueryImageToVideoTaskRequest,
    QueryImageToVideoTaskResponseBody,
    QueryImageToVideoTaskResponse,
    QueryIndividuationTextTaskRequest,
    QueryIndividuationTextTaskResponseBody,
    QueryIndividuationTextTaskResponse,
    QuerySessionInfoRequest,
    QuerySessionInfoShrinkRequest,
    QuerySessionInfoResponseBody,
    QuerySessionInfoResponse,
    QueryTextStreamResponseBody,
    QueryTextStreamResponse,
    ReleaseAgentRequest,
    ReleaseAgentResponseBody,
    ReleaseAgentResponse,
    SaveAvatarProjectRequest,
    SaveAvatarProjectResponseBody,
    SaveAvatarProjectResponse,
    SelectImageTaskResponseBody,
    SelectImageTaskResponse,
    SelectResourceRequest,
    SelectResourceResponseBody,
    SelectResourceResponse,
    SendSdkMessageRequest,
    SendSdkMessageResponseBody,
    SendSdkMessageResponse,
    SendSdkStreamMessageRequest,
    SendSdkStreamMessageResponseBody,
    SendSdkStreamMessageResponse,
    SendTextMsgRequest,
    SendTextMsgResponseBody,
    SendTextMsgResponse,
    StartAvatarSessionRequest,
    StartAvatarSessionResponseBody,
    StartAvatarSessionResponse,
    StopAvatarSessionRequest,
    StopAvatarSessionResponseBody,
    StopAvatarSessionResponse,
    StopProjectTaskRequest,
    StopProjectTaskResponseBody,
    StopProjectTaskResponse,
    SubmitImageToVideoTaskRequest,
    SubmitImageToVideoTaskResponseBody,
    SubmitImageToVideoTaskResponse,
    SubmitProjectTaskRequest,
    SubmitProjectTaskResponseBody,
    SubmitProjectTaskResponse,
    TransferPortraitStyleRequest,
    TransferPortraitStyleResponseBody,
    TransferPortraitStyleResponse,
    UpdateAgentRequest,
    UpdateAgentResponseBody,
    UpdateAgentResponse,
    BatchCreateAICoachTaskRequestStudentList,
    BatchGetProjectTaskResponseBodyResultList,
    BatchGetTrainTaskResponseBodyVoiceListVoiceMaterial,
    BatchGetTrainTaskResponseBodyVoiceList,
    BatchGetVideoClipTaskResponseBodyTaskListVideoList,
    BatchGetVideoClipTaskResponseBodyTaskList,
    BatchQueryIndividuationTextResponseBodyTextList,
    BuildAICoachScriptRecordResponseBodyData,
    CountTextResponseBodyCountTextCmdList,
    CreateAICoachTaskSessionResponseBodyScriptInfo,
    GetAICoachAssessmentPointResponseBodyAnswerListAnswerValuesKeywordValues,
    GetAICoachAssessmentPointResponseBodyAnswerListAnswerValuesScoringRules,
    GetAICoachAssessmentPointResponseBodyAnswerListAnswerValues,
    GetAICoachAssessmentPointResponseBodyAnswerListParameters,
    GetAICoachAssessmentPointResponseBodyAnswerList,
    GetAICoachCheatDetectionResponseBodyImageCheatList,
    GetAICoachCheatDetectionResponseBodyImageCheat,
    GetAICoachCheatDetectionResponseBodyVoiceCheatComparisonList,
    GetAICoachCheatDetectionResponseBodyVoiceCheatOriginalList,
    GetAICoachCheatDetectionResponseBodyVoiceCheat,
    GetAICoachScriptResponseBodyCheckCheatConfig,
    GetAICoachScriptResponseBodyCompleteStrategy,
    GetAICoachScriptResponseBodyCustomReplyRulesActionParameters,
    GetAICoachScriptResponseBodyCustomReplyRulesAction,
    GetAICoachScriptResponseBodyCustomReplyRulesMainConditionParameters,
    GetAICoachScriptResponseBodyCustomReplyRulesMainCondition,
    GetAICoachScriptResponseBodyCustomReplyRulesSubCondition,
    GetAICoachScriptResponseBodyCustomReplyRules,
    GetAICoachScriptResponseBodyExpressivenessList,
    GetAICoachScriptResponseBodyPointDeductionRuleList,
    GetAICoachScriptResponseBodyPointsAnswerListAnswerValuesKeywordValues,
    GetAICoachScriptResponseBodyPointsAnswerListAnswerValuesScoringRules,
    GetAICoachScriptResponseBodyPointsAnswerListAnswerValues,
    GetAICoachScriptResponseBodyPointsAnswerListParameters,
    GetAICoachScriptResponseBodyPointsAnswerList,
    GetAICoachScriptResponseBodyPoints,
    GetAICoachScriptResponseBodySampleDialogueList,
    GetAICoachScriptResponseBodyScoreConfigLevels,
    GetAICoachScriptResponseBodyScoreConfig,
    GetAICoachScriptResponseBodyWeights,
    GetAICoachTaskSessionHistoryResponseBodyConversationList,
    GetTextTemplateResponseBodyAvailableIndustryTextModeTypesTextStyles,
    GetTextTemplateResponseBodyAvailableIndustryTextModeTypes,
    GetTextTemplateResponseBodyAvailableIndustry,
    ListAICoachScriptPageResponseBodyListCompleteStrategy,
    ListAICoachScriptPageResponseBodyListCustomReplyRulesActionParameters,
    ListAICoachScriptPageResponseBodyListCustomReplyRulesAction,
    ListAICoachScriptPageResponseBodyListCustomReplyRulesMainConditionParameters,
    ListAICoachScriptPageResponseBodyListCustomReplyRulesMainCondition,
    ListAICoachScriptPageResponseBodyListCustomReplyRulesSubCondition,
    ListAICoachScriptPageResponseBodyListCustomReplyRules,
    ListAICoachScriptPageResponseBodyListSampleDialogueList,
    ListAICoachScriptPageResponseBodyListScoreConfigLevels,
    ListAICoachScriptPageResponseBodyListScoreConfig,
    ListAICoachScriptPageResponseBodyListWeights,
    ListAICoachScriptPageResponseBodyList,
    ListAICoachTaskPageResponseBodyTaskList,
    ListAgentsResponseBodyList,
    ListAvatarProjectResponseBodyQueryAvatarProjectResultList,
    QueryAvatarProjectResponseBodyFramesLayersMaterial,
    QueryAvatarProjectResponseBodyFramesLayers,
    QueryAvatarProjectResponseBodyFramesVideoScript,
    QueryAvatarProjectResponseBodyFrames,
    QueryAvatarResourceResponseBodyQueryResourceInfoList,
    QueryIndividuationTextTaskResponseBodyTextList,
    QuerySessionInfoResponseBodyQueryResourceInfoList,
    SaveAvatarProjectRequestFramesLayersMaterial,
    SaveAvatarProjectRequestFramesLayers,
    SaveAvatarProjectRequestFramesVideoScript,
    SaveAvatarProjectRequestFrames,
    SelectImageTaskResponseBodyImageInfos,
    SelectResourceResponseBodyResourceInfoList,
    SubmitProjectTaskRequestFramesLayersMaterialMask,
    SubmitProjectTaskRequestFramesLayersMaterial,
    SubmitProjectTaskRequestFramesLayers,
    SubmitProjectTaskRequestFramesSubtitle,
    SubmitProjectTaskRequestFramesVideoScript,
    SubmitProjectTaskRequestFrames
]



# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class OperateAvatarProjectRequest(DaraModel):
    def __init__(
        self,
        operate_type: str = None,
        project_id: str = None,
        res_channel_number: int = None,
        res_type: str = None,
    ):
        self.operate_type = operate_type
        self.project_id = project_id
        self.res_channel_number = res_channel_number
        self.res_type = res_type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.operate_type is not None:
            result['operateType'] = self.operate_type

        if self.project_id is not None:
            result['projectId'] = self.project_id

        if self.res_channel_number is not None:
            result['resChannelNumber'] = self.res_channel_number

        if self.res_type is not None:
            result['resType'] = self.res_type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('operateType') is not None:
            self.operate_type = m.get('operateType')

        if m.get('projectId') is not None:
            self.project_id = m.get('projectId')

        if m.get('resChannelNumber') is not None:
            self.res_channel_number = m.get('resChannelNumber')

        if m.get('resType') is not None:
            self.res_type = m.get('resType')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class IllustrationTask(DaraModel):
    def __init__(
        self,
        gmt_create: str = None,
        gmt_modified: str = None,
        illustration_ids: List[int] = None,
        illustration_task_id: int = None,
        task_status: str = None,
        text_id: int = None,
    ):
        self.gmt_create = gmt_create
        self.gmt_modified = gmt_modified
        self.illustration_ids = illustration_ids
        self.illustration_task_id = illustration_task_id
        self.task_status = task_status
        self.text_id = text_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.gmt_create is not None:
            result['gmtCreate'] = self.gmt_create

        if self.gmt_modified is not None:
            result['gmtModified'] = self.gmt_modified

        if self.illustration_ids is not None:
            result['illustrationIds'] = self.illustration_ids

        if self.illustration_task_id is not None:
            result['illustrationTaskId'] = self.illustration_task_id

        if self.task_status is not None:
            result['taskStatus'] = self.task_status

        if self.text_id is not None:
            result['textId'] = self.text_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('gmtCreate') is not None:
            self.gmt_create = m.get('gmtCreate')

        if m.get('gmtModified') is not None:
            self.gmt_modified = m.get('gmtModified')

        if m.get('illustrationIds') is not None:
            self.illustration_ids = m.get('illustrationIds')

        if m.get('illustrationTaskId') is not None:
            self.illustration_task_id = m.get('illustrationTaskId')

        if m.get('taskStatus') is not None:
            self.task_status = m.get('taskStatus')

        if m.get('textId') is not None:
            self.text_id = m.get('textId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class CreateAICoachTaskSessionResponseBody(DaraModel):
    def __init__(
        self,
        channel_token: str = None,
        request_id: str = None,
        script_info: main_models.CreateAICoachTaskSessionResponseBodyScriptInfo = None,
        session_id: str = None,
        session_status: int = None,
        token: str = None,
        web_socket_url: str = None,
    ):
        # rtctoken
        self.channel_token = channel_token
        self.request_id = request_id
        self.script_info = script_info
        self.session_id = session_id
        self.session_status = session_status
        # Token
        self.token = token
        self.web_socket_url = web_socket_url

    def validate(self):
        if self.script_info:
            self.script_info.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.channel_token is not None:
            result['channelToken'] = self.channel_token

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.script_info is not None:
            result['scriptInfo'] = self.script_info.to_map()

        if self.session_id is not None:
            result['sessionId'] = self.session_id

        if self.session_status is not None:
            result['sessionStatus'] = self.session_status

        if self.token is not None:
            result['token'] = self.token

        if self.web_socket_url is not None:
            result['webSocketUrl'] = self.web_socket_url

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('channelToken') is not None:
            self.channel_token = m.get('channelToken')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('scriptInfo') is not None:
            temp_model = main_models.CreateAICoachTaskSessionResponseBodyScriptInfo()
            self.script_info = temp_model.from_map(m.get('scriptInfo'))

        if m.get('sessionId') is not None:
            self.session_id = m.get('sessionId')

        if m.get('sessionStatus') is not None:
            self.session_status = m.get('sessionStatus')

        if m.get('token') is not None:
            self.token = m.get('token')

        if m.get('webSocketUrl') is not None:
            self.web_socket_url = m.get('webSocketUrl')

        return self

class CreateAICoachTaskSessionResponseBodyScriptInfo(DaraModel):
    def __init__(
        self,
        agent_icon_url: str = None,
        character_name: str = None,
        dialogue_text_flag: bool = None,
        dialogue_tip_flag: bool = None,
        initiator: str = None,
        input_type_list: List[str] = None,
        max_duration: int = None,
        script_desc: str = None,
        script_name: str = None,
        script_record_id: str = None,
        script_type: int = None,
        sparring_tip_content: str = None,
        sparring_tip_title: str = None,
        student_think_time_flag: bool = None,
        student_think_time_limit: int = None,
    ):
        self.agent_icon_url = agent_icon_url
        self.character_name = character_name
        self.dialogue_text_flag = dialogue_text_flag
        self.dialogue_tip_flag = dialogue_tip_flag
        self.initiator = initiator
        self.input_type_list = input_type_list
        self.max_duration = max_duration
        self.script_desc = script_desc
        self.script_name = script_name
        self.script_record_id = script_record_id
        self.script_type = script_type
        self.sparring_tip_content = sparring_tip_content
        self.sparring_tip_title = sparring_tip_title
        self.student_think_time_flag = student_think_time_flag
        self.student_think_time_limit = student_think_time_limit

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.agent_icon_url is not None:
            result['agentIconUrl'] = self.agent_icon_url

        if self.character_name is not None:
            result['characterName'] = self.character_name

        if self.dialogue_text_flag is not None:
            result['dialogueTextFlag'] = self.dialogue_text_flag

        if self.dialogue_tip_flag is not None:
            result['dialogueTipFlag'] = self.dialogue_tip_flag

        if self.initiator is not None:
            result['initiator'] = self.initiator

        if self.input_type_list is not None:
            result['inputTypeList'] = self.input_type_list

        if self.max_duration is not None:
            result['maxDuration'] = self.max_duration

        if self.script_desc is not None:
            result['scriptDesc'] = self.script_desc

        if self.script_name is not None:
            result['scriptName'] = self.script_name

        if self.script_record_id is not None:
            result['scriptRecordId'] = self.script_record_id

        if self.script_type is not None:
            result['scriptType'] = self.script_type

        if self.sparring_tip_content is not None:
            result['sparringTipContent'] = self.sparring_tip_content

        if self.sparring_tip_title is not None:
            result['sparringTipTitle'] = self.sparring_tip_title

        if self.student_think_time_flag is not None:
            result['studentThinkTimeFlag'] = self.student_think_time_flag

        if self.student_think_time_limit is not None:
            result['studentThinkTimeLimit'] = self.student_think_time_limit

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('agentIconUrl') is not None:
            self.agent_icon_url = m.get('agentIconUrl')

        if m.get('characterName') is not None:
            self.character_name = m.get('characterName')

        if m.get('dialogueTextFlag') is not None:
            self.dialogue_text_flag = m.get('dialogueTextFlag')

        if m.get('dialogueTipFlag') is not None:
            self.dialogue_tip_flag = m.get('dialogueTipFlag')

        if m.get('initiator') is not None:
            self.initiator = m.get('initiator')

        if m.get('inputTypeList') is not None:
            self.input_type_list = m.get('inputTypeList')

        if m.get('maxDuration') is not None:
            self.max_duration = m.get('maxDuration')

        if m.get('scriptDesc') is not None:
            self.script_desc = m.get('scriptDesc')

        if m.get('scriptName') is not None:
            self.script_name = m.get('scriptName')

        if m.get('scriptRecordId') is not None:
            self.script_record_id = m.get('scriptRecordId')

        if m.get('scriptType') is not None:
            self.script_type = m.get('scriptType')

        if m.get('sparringTipContent') is not None:
            self.sparring_tip_content = m.get('sparringTipContent')

        if m.get('sparringTipTitle') is not None:
            self.sparring_tip_title = m.get('sparringTipTitle')

        if m.get('studentThinkTimeFlag') is not None:
            self.student_think_time_flag = m.get('studentThinkTimeFlag')

        if m.get('studentThinkTimeLimit') is not None:
            self.student_think_time_limit = m.get('studentThinkTimeLimit')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class GetTextTemplateResponseBody(DaraModel):
    def __init__(
        self,
        available_industry: main_models.GetTextTemplateResponseBodyAvailableIndustry = None,
        request_id: str = None,
    ):
        self.available_industry = available_industry
        self.request_id = request_id

    def validate(self):
        if self.available_industry:
            self.available_industry.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.available_industry is not None:
            result['availableIndustry'] = self.available_industry.to_map()

        if self.request_id is not None:
            result['requestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('availableIndustry') is not None:
            temp_model = main_models.GetTextTemplateResponseBodyAvailableIndustry()
            self.available_industry = temp_model.from_map(m.get('availableIndustry'))

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        return self

class GetTextTemplateResponseBodyAvailableIndustry(DaraModel):
    def __init__(
        self,
        name: str = None,
        text_mode_types: List[main_models.GetTextTemplateResponseBodyAvailableIndustryTextModeTypes] = None,
    ):
        self.name = name
        self.text_mode_types = text_mode_types

    def validate(self):
        if self.text_mode_types:
            for v1 in self.text_mode_types:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.name is not None:
            result['name'] = self.name

        result['textModeTypes'] = []
        if self.text_mode_types is not None:
            for k1 in self.text_mode_types:
                result['textModeTypes'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('name') is not None:
            self.name = m.get('name')

        self.text_mode_types = []
        if m.get('textModeTypes') is not None:
            for k1 in m.get('textModeTypes'):
                temp_model = main_models.GetTextTemplateResponseBodyAvailableIndustryTextModeTypes()
                self.text_mode_types.append(temp_model.from_map(k1))

        return self

class GetTextTemplateResponseBodyAvailableIndustryTextModeTypes(DaraModel):
    def __init__(
        self,
        name: str = None,
        text_styles: List[main_models.GetTextTemplateResponseBodyAvailableIndustryTextModeTypesTextStyles] = None,
    ):
        self.name = name
        self.text_styles = text_styles

    def validate(self):
        if self.text_styles:
            for v1 in self.text_styles:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.name is not None:
            result['name'] = self.name

        result['textStyles'] = []
        if self.text_styles is not None:
            for k1 in self.text_styles:
                result['textStyles'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('name') is not None:
            self.name = m.get('name')

        self.text_styles = []
        if m.get('textStyles') is not None:
            for k1 in m.get('textStyles'):
                temp_model = main_models.GetTextTemplateResponseBodyAvailableIndustryTextModeTypesTextStyles()
                self.text_styles.append(temp_model.from_map(k1))

        return self

class GetTextTemplateResponseBodyAvailableIndustryTextModeTypesTextStyles(DaraModel):
    def __init__(
        self,
        desc: str = None,
        disabled: bool = None,
        name: str = None,
        template_key: str = None,
    ):
        self.desc = desc
        self.disabled = disabled
        self.name = name
        self.template_key = template_key

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.desc is not None:
            result['desc'] = self.desc

        if self.disabled is not None:
            result['disabled'] = self.disabled

        if self.name is not None:
            result['name'] = self.name

        if self.template_key is not None:
            result['templateKey'] = self.template_key

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('desc') is not None:
            self.desc = m.get('desc')

        if m.get('disabled') is not None:
            self.disabled = m.get('disabled')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('templateKey') is not None:
            self.template_key = m.get('templateKey')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class GetAICoachTaskSessionHistoryResponseBody(DaraModel):
    def __init__(
        self,
        conversation_list: List[main_models.GetAICoachTaskSessionHistoryResponseBodyConversationList] = None,
        duration: int = None,
        end_time: str = None,
        pause_duration: int = None,
        request_id: str = None,
        script_name: str = None,
        start_time: str = None,
        status: str = None,
        total: int = None,
        uid: str = None,
    ):
        self.conversation_list = conversation_list
        self.duration = duration
        self.end_time = end_time
        self.pause_duration = pause_duration
        self.request_id = request_id
        self.script_name = script_name
        self.start_time = start_time
        self.status = status
        self.total = total
        self.uid = uid

    def validate(self):
        if self.conversation_list:
            for v1 in self.conversation_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['conversationList'] = []
        if self.conversation_list is not None:
            for k1 in self.conversation_list:
                result['conversationList'].append(k1.to_map() if k1 else None)

        if self.duration is not None:
            result['duration'] = self.duration

        if self.end_time is not None:
            result['endTime'] = self.end_time

        if self.pause_duration is not None:
            result['pauseDuration'] = self.pause_duration

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.script_name is not None:
            result['scriptName'] = self.script_name

        if self.start_time is not None:
            result['startTime'] = self.start_time

        if self.status is not None:
            result['status'] = self.status

        if self.total is not None:
            result['total'] = self.total

        if self.uid is not None:
            result['uid'] = self.uid

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.conversation_list = []
        if m.get('conversationList') is not None:
            for k1 in m.get('conversationList'):
                temp_model = main_models.GetAICoachTaskSessionHistoryResponseBodyConversationList()
                self.conversation_list.append(temp_model.from_map(k1))

        if m.get('duration') is not None:
            self.duration = m.get('duration')

        if m.get('endTime') is not None:
            self.end_time = m.get('endTime')

        if m.get('pauseDuration') is not None:
            self.pause_duration = m.get('pauseDuration')

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('scriptName') is not None:
            self.script_name = m.get('scriptName')

        if m.get('startTime') is not None:
            self.start_time = m.get('startTime')

        if m.get('status') is not None:
            self.status = m.get('status')

        if m.get('total') is not None:
            self.total = m.get('total')

        if m.get('uid') is not None:
            self.uid = m.get('uid')

        return self

class GetAICoachTaskSessionHistoryResponseBodyConversationList(DaraModel):
    def __init__(
        self,
        audio_url: str = None,
        date_label: str = None,
        evaluation_feedback: str = None,
        evaluation_result: str = None,
        message: str = None,
        record_id: str = None,
        role: str = None,
    ):
        self.audio_url = audio_url
        self.date_label = date_label
        self.evaluation_feedback = evaluation_feedback
        self.evaluation_result = evaluation_result
        self.message = message
        self.record_id = record_id
        self.role = role

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.audio_url is not None:
            result['audioUrl'] = self.audio_url

        if self.date_label is not None:
            result['dateLabel'] = self.date_label

        if self.evaluation_feedback is not None:
            result['evaluationFeedback'] = self.evaluation_feedback

        if self.evaluation_result is not None:
            result['evaluationResult'] = self.evaluation_result

        if self.message is not None:
            result['message'] = self.message

        if self.record_id is not None:
            result['recordId'] = self.record_id

        if self.role is not None:
            result['role'] = self.role

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('audioUrl') is not None:
            self.audio_url = m.get('audioUrl')

        if m.get('dateLabel') is not None:
            self.date_label = m.get('dateLabel')

        if m.get('evaluationFeedback') is not None:
            self.evaluation_feedback = m.get('evaluationFeedback')

        if m.get('evaluationResult') is not None:
            self.evaluation_result = m.get('evaluationResult')

        if m.get('message') is not None:
            self.message = m.get('message')

        if m.get('recordId') is not None:
            self.record_id = m.get('recordId')

        if m.get('role') is not None:
            self.role = m.get('role')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class KnowledgeBaseListResult(DaraModel):
    def __init__(
        self,
        knowledge_bases: List[main_models.KnowledgeBaseInfo] = None,
        request_id: str = None,
        total: int = None,
    ):
        self.knowledge_bases = knowledge_bases
        self.request_id = request_id
        # This parameter is required.
        self.total = total

    def validate(self):
        if self.knowledge_bases:
            for v1 in self.knowledge_bases:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['knowledgeBases'] = []
        if self.knowledge_bases is not None:
            for k1 in self.knowledge_bases:
                result['knowledgeBases'].append(k1.to_map() if k1 else None)

        if self.request_id is not None:
            result['requestId'] = self.request_id

        if self.total is not None:
            result['total'] = self.total

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.knowledge_bases = []
        if m.get('knowledgeBases') is not None:
            for k1 in m.get('knowledgeBases'):
                temp_model = main_models.KnowledgeBaseInfo()
                self.knowledge_bases.append(temp_model.from_map(k1))

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        if m.get('total') is not None:
            self.total = m.get('total')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class AddDocumentInfo(DaraModel):
    def __init__(
        self,
        document_type: str = None,
        name: str = None,
        url: str = None,
    ):
        # This parameter is required.
        self.document_type = document_type
        # This parameter is required.
        self.name = name
        # This parameter is required.
        self.url = url

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.document_type is not None:
            result['documentType'] = self.document_type

        if self.name is not None:
            result['name'] = self.name

        if self.url is not None:
            result['url'] = self.url

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('documentType') is not None:
            self.document_type = m.get('documentType')

        if m.get('name') is not None:
            self.name = m.get('name')

        if m.get('url') is not None:
            self.url = m.get('url')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class KnowledgeBaseInfo(DaraModel):
    def __init__(
        self,
        description: str = None,
        id: str = None,
        industry: str = None,
        knowledge_base_type: str = None,
        name: str = None,
    ):
        self.description = description
        self.id = id
        self.industry = industry
        self.knowledge_base_type = knowledge_base_type
        self.name = name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.description is not None:
            result['description'] = self.description

        if self.id is not None:
            result['id'] = self.id

        if self.industry is not None:
            result['industry'] = self.industry

        if self.knowledge_base_type is not None:
            result['knowledgeBaseType'] = self.knowledge_base_type

        if self.name is not None:
            result['name'] = self.name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('description') is not None:
            self.description = m.get('description')

        if m.get('id') is not None:
            self.id = m.get('id')

        if m.get('industry') is not None:
            self.industry = m.get('industry')

        if m.get('knowledgeBaseType') is not None:
            self.knowledge_base_type = m.get('knowledgeBaseType')

        if m.get('name') is not None:
            self.name = m.get('name')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class AnchorResponse(DaraModel):
    def __init__(
        self,
        anchor_category: str = None,
        anchor_id: str = None,
        anchor_material_name: str = None,
        anchor_type: str = None,
        cover_height: int = None,
        cover_rate: str = None,
        cover_thumbnail_url: str = None,
        cover_url: str = None,
        cover_weight: int = None,
        digital_human_type: str = None,
        gender: str = None,
        resource_type_desc: str = None,
        status: str = None,
        support_bg_change: int = None,
        use_scene: str = None,
    ):
        self.anchor_category = anchor_category
        self.anchor_id = anchor_id
        self.anchor_material_name = anchor_material_name
        self.anchor_type = anchor_type
        self.cover_height = cover_height
        self.cover_rate = cover_rate
        self.cover_thumbnail_url = cover_thumbnail_url
        self.cover_url = cover_url
        self.cover_weight = cover_weight
        self.digital_human_type = digital_human_type
        self.gender = gender
        self.resource_type_desc = resource_type_desc
        self.status = status
        self.support_bg_change = support_bg_change
        self.use_scene = use_scene

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.anchor_category is not None:
            result['anchorCategory'] = self.anchor_category

        if self.anchor_id is not None:
            result['anchorId'] = self.anchor_id

        if self.anchor_material_name is not None:
            result['anchorMaterialName'] = self.anchor_material_name

        if self.anchor_type is not None:
            result['anchorType'] = self.anchor_type

        if self.cover_height is not None:
            result['coverHeight'] = self.cover_height

        if self.cover_rate is not None:
            result['coverRate'] = self.cover_rate

        if self.cover_thumbnail_url is not None:
            result['coverThumbnailUrl'] = self.cover_thumbnail_url

        if self.cover_url is not None:
            result['coverUrl'] = self.cover_url

        if self.cover_weight is not None:
            result['coverWeight'] = self.cover_weight

        if self.digital_human_type is not None:
            result['digitalHumanType'] = self.digital_human_type

        if self.gender is not None:
            result['gender'] = self.gender

        if self.resource_type_desc is not None:
            result['resourceTypeDesc'] = self.resource_type_desc

        if self.status is not None:
            result['status'] = self.status

        if self.support_bg_change is not None:
            result['supportBgChange'] = self.support_bg_change

        if self.use_scene is not None:
            result['useScene'] = self.use_scene

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('anchorCategory') is not None:
            self.anchor_category = m.get('anchorCategory')

        if m.get('anchorId') is not None:
            self.anchor_id = m.get('anchorId')

        if m.get('anchorMaterialName') is not None:
            self.anchor_material_name = m.get('anchorMaterialName')

        if m.get('anchorType') is not None:
            self.anchor_type = m.get('anchorType')

        if m.get('coverHeight') is not None:
            self.cover_height = m.get('coverHeight')

        if m.get('coverRate') is not None:
            self.cover_rate = m.get('coverRate')

        if m.get('coverThumbnailUrl') is not None:
            self.cover_thumbnail_url = m.get('coverThumbnailUrl')

        if m.get('coverUrl') is not None:
            self.cover_url = m.get('coverUrl')

        if m.get('coverWeight') is not None:
            self.cover_weight = m.get('coverWeight')

        if m.get('digitalHumanType') is not None:
            self.digital_human_type = m.get('digitalHumanType')

        if m.get('gender') is not None:
            self.gender = m.get('gender')

        if m.get('resourceTypeDesc') is not None:
            self.resource_type_desc = m.get('resourceTypeDesc')

        if m.get('status') is not None:
            self.status = m.get('status')

        if m.get('supportBgChange') is not None:
            self.support_bg_change = m.get('supportBgChange')

        if m.get('useScene') is not None:
            self.use_scene = m.get('useScene')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class QueryAvatarResourceResponseBody(DaraModel):
    def __init__(
        self,
        query_resource_info_list: List[main_models.QueryAvatarResourceResponseBodyQueryResourceInfoList] = None,
        request_id: str = None,
    ):
        self.query_resource_info_list = query_resource_info_list
        self.request_id = request_id

    def validate(self):
        if self.query_resource_info_list:
            for v1 in self.query_resource_info_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['queryResourceInfoList'] = []
        if self.query_resource_info_list is not None:
            for k1 in self.query_resource_info_list:
                result['queryResourceInfoList'].append(k1.to_map() if k1 else None)

        if self.request_id is not None:
            result['requestId'] = self.request_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.query_resource_info_list = []
        if m.get('queryResourceInfoList') is not None:
            for k1 in m.get('queryResourceInfoList'):
                temp_model = main_models.QueryAvatarResourceResponseBodyQueryResourceInfoList()
                self.query_resource_info_list.append(temp_model.from_map(k1))

        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        return self

class QueryAvatarResourceResponseBodyQueryResourceInfoList(DaraModel):
    def __init__(
        self,
        resource_id: str = None,
        type: str = None,
        valid_period_time: str = None,
    ):
        self.resource_id = resource_id
        self.type = type
        self.valid_period_time = valid_period_time

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.resource_id is not None:
            result['resourceId'] = self.resource_id

        if self.type is not None:
            result['type'] = self.type

        if self.valid_period_time is not None:
            result['validPeriodTime'] = self.valid_period_time

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('resourceId') is not None:
            self.resource_id = m.get('resourceId')

        if m.get('type') is not None:
            self.type = m.get('type')

        if m.get('validPeriodTime') is not None:
            self.valid_period_time = m.get('validPeriodTime')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class TextThemeListResult(DaraModel):
    def __init__(
        self,
        request_id: str = None,
        text_theme_list: List[main_models.TextTheme] = None,
    ):
        self.request_id = request_id
        # This parameter is required.
        self.text_theme_list = text_theme_list

    def validate(self):
        if self.text_theme_list:
            for v1 in self.text_theme_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.request_id is not None:
            result['requestId'] = self.request_id

        result['textThemeList'] = []
        if self.text_theme_list is not None:
            for k1 in self.text_theme_list:
                result['textThemeList'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('requestId') is not None:
            self.request_id = m.get('requestId')

        self.text_theme_list = []
        if m.get('textThemeList') is not None:
            for k1 in m.get('textThemeList'):
                temp_model = main_models.TextTheme()
                self.text_theme_list.append(temp_model.from_map(k1))

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class TextTask(DaraModel):
    def __init__(
        self,
        agent_id: str = None,
        agent_name: str = None,
        content_requirement: str = None,
        gmt_create: str = None,
        gmt_modified: str = None,
        introduction: str = None,
        nums: int = None,
        point: str = None,
        reference_tag: main_models.ReferenceTag = None,
        related_rag_ids: List[int] = None,
        style: str = None,
        target: str = None,
        text_ids: List[int] = None,
        text_mode_type: str = None,
        text_task_id: int = None,
        text_task_status: str = None,
        texts: List[main_models.Text] = None,
        theme: str = None,
        theme_desc: str = None,
    ):
        self.agent_id = agent_id
        self.agent_name = agent_name
        self.content_requirement = content_requirement
        self.gmt_create = gmt_create
        self.gmt_modified = gmt_modified
        self.introduction = introduction
        # This parameter is required.
        self.nums = nums
        self.point = point
        self.reference_tag = reference_tag
        self.related_rag_ids = related_rag_ids
        # This parameter is required.
        self.style = style
        self.target = target
        self.text_ids = text_ids
        # This parameter is required.
        self.text_mode_type = text_mode_type
        self.text_task_id = text_task_id
        self.text_task_status = text_task_status
        self.texts = texts
        self.theme = theme
        self.theme_desc = theme_desc

    def validate(self):
        if self.reference_tag:
            self.reference_tag.validate()
        if self.texts:
            for v1 in self.texts:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.agent_id is not None:
            result['agentId'] = self.agent_id

        if self.agent_name is not None:
            result['agentName'] = self.agent_name

        if self.content_requirement is not None:
            result['contentRequirement'] = self.content_requirement

        if self.gmt_create is not None:
            result['gmtCreate'] = self.gmt_create

        if self.gmt_modified is not None:
            result['gmtModified'] = self.gmt_modified

        if self.introduction is not None:
            result['introduction'] = self.introduction

        if self.nums is not None:
            result['nums'] = self.nums

        if self.point is not None:
            result['point'] = self.point

        if self.reference_tag is not None:
            result['referenceTag'] = self.reference_tag.to_map()

        if self.related_rag_ids is not None:
            result['relatedRagIds'] = self.related_rag_ids

        if self.style is not None:
            result['style'] = self.style

        if self.target is not None:
            result['target'] = self.target

        if self.text_ids is not None:
            result['textIds'] = self.text_ids

        if self.text_mode_type is not None:
            result['textModeType'] = self.text_mode_type

        if self.text_task_id is not None:
            result['textTaskId'] = self.text_task_id

        if self.text_task_status is not None:
            result['textTaskStatus'] = self.text_task_status

        result['texts'] = []
        if self.texts is not None:
            for k1 in self.texts:
                result['texts'].append(k1.to_map() if k1 else None)

        if self.theme is not None:
            result['theme'] = self.theme

        if self.theme_desc is not None:
            result['themeDesc'] = self.theme_desc

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('agentId') is not None:
            self.agent_id = m.get('agentId')

        if m.get('agentName') is not None:
            self.agent_name = m.get('agentName')

        if m.get('contentRequirement') is not None:
            self.content_requirement = m.get('contentRequirement')

        if m.get('gmtCreate') is not None:
            self.gmt_create = m.get('gmtCreate')

        if m.get('gmtModified') is not None:
            self.gmt_modified = m.get('gmtModified')

        if m.get('introduction') is not None:
            self.introduction = m.get('introduction')

        if m.get('nums') is not None:
            self.nums = m.get('nums')

        if m.get('point') is not None:
            self.point = m.get('point')

        if m.get('referenceTag') is not None:
            temp_model = main_models.ReferenceTag()
            self.reference_tag = temp_model.from_map(m.get('referenceTag'))

        if m.get('relatedRagIds') is not None:
            self.related_rag_ids = m.get('relatedRagIds')

        if m.get('style') is not None:
            self.style = m.get('style')

        if m.get('target') is not None:
            self.target = m.get('target')

        if m.get('textIds') is not None:
            self.text_ids = m.get('textIds')

        if m.get('textModeType') is not None:
            self.text_mode_type = m.get('textModeType')

        if m.get('textTaskId') is not None:
            self.text_task_id = m.get('textTaskId')

        if m.get('textTaskStatus') is not None:
            self.text_task_status = m.get('textTaskStatus')

        self.texts = []
        if m.get('texts') is not None:
            for k1 in m.get('texts'):
                temp_model = main_models.Text()
                self.texts.append(temp_model.from_map(k1))

        if m.get('theme') is not None:
            self.theme = m.get('theme')

        if m.get('themeDesc') is not None:
            self.theme_desc = m.get('themeDesc')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from darabonba.model import DaraModel

class Text(DaraModel):
    def __init__(
        self,
        agent_id: str = None,
        agent_name: str = None,
        desc: str = None,
        err_msg: str = None,
        gmt_create: str = None,
        gmt_modified: str = None,
        illustration_task_id_list: List[int] = None,
        publish_status: str = None,
        text_content: str = None,
        text_id: int = None,
        text_illustration_tag: bool = None,
        text_mode_type: str = None,
        text_status: str = None,
        text_style_type: str = None,
        text_task_id: int = None,
        text_themes: List[str] = None,
        title: str = None,
        user_name_create: str = None,
        user_name_modified: str = None,
    ):
        self.agent_id = agent_id
        self.agent_name = agent_name
        # This parameter is required.
        self.desc = desc
        self.err_msg = err_msg
        self.gmt_create = gmt_create
        self.gmt_modified = gmt_modified
        self.illustration_task_id_list = illustration_task_id_list
        self.publish_status = publish_status
        self.text_content = text_content
        # This parameter is required.
        self.text_id = text_id
        self.text_illustration_tag = text_illustration_tag
        self.text_mode_type = text_mode_type
        # This parameter is required.
        self.text_status = text_status
        self.text_style_type = text_style_type
        # This parameter is required.
        self.text_task_id = text_task_id
        self.text_themes = text_themes
        self.title = title
        # This parameter is required.
        self.user_name_create = user_name_create
        # This parameter is required.
        self.user_name_modified = user_name_modified

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.agent_id is not None:
            result['agentId'] = self.agent_id

        if self.agent_name is not None:
            result['agentName'] = self.agent_name

        if self.desc is not None:
            result['desc'] = self.desc

        if self.err_msg is not None:
            result['errMsg'] = self.err_msg

        if self.gmt_create is not None:
            result['gmtCreate'] = self.gmt_create

        if self.gmt_modified is not None:
            result['gmtModified'] = self.gmt_modified

        if self.illustration_task_id_list is not None:
            result['illustrationTaskIdList'] = self.illustration_task_id_list

        if self.publish_status is not None:
            result['publishStatus'] = self.publish_status

        if self.text_content is not None:
            result['textContent'] = self.text_content

        if self.text_id is not None:
            result['textId'] = self.text_id

        if self.text_illustration_tag is not None:
            result['textIllustrationTag'] = self.text_illustration_tag

        if self.text_mode_type is not None:
            result['textModeType'] = self.text_mode_type

        if self.text_status is not None:
            result['textStatus'] = self.text_status

        if self.text_style_type is not None:
            result['textStyleType'] = self.text_style_type

        if self.text_task_id is not None:
            result['textTaskId'] = self.text_task_id

        if self.text_themes is not None:
            result['textThemes'] = self.text_themes

        if self.title is not None:
            result['title'] = self.title

        if self.user_name_create is not None:
            result['userNameCreate'] = self.user_name_create

        if self.user_name_modified is not None:
            result['userNameModified'] = self.user_name_modified

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('agentId') is not None:
            self.agent_id = m.get('agentId')

        if m.get('agentName') is not None:
            self.agent_name = m.get('agentName')

        if m.get('desc') is not None:
            self.desc = m.get('desc')

        if m.get('errMsg') is not None:
            self.err_msg = m.get('errMsg')

        if m.get('gmtCreate') is not None:
            self.gmt_create = m.get('gmtCreate')

        if m.get('gmtModified') is not None:
            self.gmt_modified = m.get('gmtModified')

        if m.get('illustrationTaskIdList') is not None:
            self.illustration_task_id_list = m.get('illustrationTaskIdList')

        if m.get('publishStatus') is not None:
            self.publish_status = m.get('publishStatus')

        if m.get('textContent') is not None:
            self.text_content = m.get('textContent')

        if m.get('textId') is not None:
            self.text_id = m.get('textId')

        if m.get('textIllustrationTag') is not None:
            self.text_illustration_tag = m.get('textIllustrationTag')

        if m.get('textModeType') is not None:
            self.text_mode_type = m.get('textModeType')

        if m.get('textStatus') is not None:
            self.text_status = m.get('textStatus')

        if m.get('textStyleType') is not None:
            self.text_style_type = m.get('textStyleType')

        if m.get('textTaskId') is not None:
            self.text_task_id = m.get('textTaskId')

        if m.get('textThemes') is not None:
            self.text_themes = m.get('textThemes')

        if m.get('title') is not None:
            self.title = m.get('title')

        if m.get('userNameCreate') is not None:
            self.user_name_create = m.get('userNameCreate')

        if m.get('userNameModified') is not None:
            self.user_name_modified = m.get('userNameModified')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_intelligentcreation20240313 import models as main_models
from darabonba.model import DaraModel

class SaveAvatarProjectRequest(DaraModel):
    def __init__(
        self,
        agent_id: str = None,
        bit_rate: str = None,
        frame_rate: str = None,
        frames: List[main_models.SaveAvatarProjectRequestFrames] = None,
        operate_type: str = None,
        project_id: str = None,
        project_name: str = None,
        res_spec_type: str = None,
        resolution: str = None,
        scale_type: str = None,
        script_model_tag: str = None,
        synchronized_display: str = None,
    ):
        self.agent_id = agent_id
        self.bit_rate = bit_rate
        self.frame_rate = frame_rate
        self.frames = frames
        self.operate_type = operate_type
        self.project_id = project_id
        self.project_name = project_name
        self.res_spec_type = res_spec_type
        self.resolution = resolution
        self.scale_type = scale_type
        self.script_model_tag = script_model_tag
        self.synchronized_display = synchronized_display

    def validate(self):
        if self.frames:
            for v1 in self.frames:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.agent_id is not None:
            result['agentId'] = self.agent_id

        if self.bit_rate is not None:
            result['bitRate'] = self.bit_rate

        if self.frame_rate is not None:
            result['frameRate'] = self.frame_rate

        result['frames'] = []
        if self.frames is not None:
            for k1 in self.frames:
                result['frames'].append(k1.to_map() if k1 else None)

        if self.operate_type is not None:
            result['operateType'] = self.operate_type

        if self.project_id is not None:
            result['projectId'] = self.project_id

        if self.project_name is not None:
            result['projectName'] = self.project_name

        if self.res_spec_type is not None:
            result['resSpecType'] = self.res_spec_type

        if self.resolution is not None:
            result['resolution'] = self.resolution

        if self.scale_type is not None:
            result['scaleType'] = self.scale_type

        if self.script_model_tag is not None:
            result['scriptModelTag'] = self.script_model_tag

        if self.synchronized_display is not None:
            result['synchronizedDisplay'] = self.synchronized_display

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('agentId') is not None:
            self.agent_id = m.get('agentId')

        if m.get('bitRate') is not None:
            self.bit_rate = m.get('bitRate')

        if m.get('frameRate') is not None:
            self.frame_rate = m.get('frameRate')

        self.frames = []
        if m.get('frames') is not None:
            for k1 in m.get('frames'):
                temp_model = main_models.SaveAvatarProjectRequestFrames()
                self.frames.append(temp_model.from_map(k1))

        if m.get('operateType') is not None:
            self.operate_type = m.get('operateType')

        if m.get('projectId') is not None:
            self.project_id = m.get('projectId')

        if m.get('projectName') is not None:
            self.project_name = m.get('projectName')

        if m.get('resSpecType') is not None:
            self.res_spec_type = m.get('resSpecType')

        if m.get('resolution') is not None:
            self.resolution = m.get('resolution')

        if m.get('scaleType') is not None:
            self.scale_type = m.get('scaleType')

        if m.get('scriptModelTag') is not None:
            self.script_model_tag = m.get('scriptModelTag')

        if m.get('synchronizedDisplay') is not None:
            self.synchronized_display = m.get('synchronizedDisplay')

        return self

class SaveAvatarProjectRequestFrames(DaraModel):
    def __init__(
        self,
        index: int = None,
        layers: List[main_models.SaveAvatarProjectRequestFramesLayers] = None,
        video_script: main_models.SaveAvatarProjectRequestFramesVideoScript = None,
    ):
        self.index = index
        self.layers = layers
        self.video_script = video_script

    def validate(self):
        if self.layers:
            for v1 in self.layers:
                 if v1:
                    v1.validate()
        if self.video_script:
            self.video_script.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.index is not None:
            result['index'] = self.index

        result['layers'] = []
        if self.layers is not None:
            for k1 in self.layers:
                result['layers'].append(k1.to_map() if k1 else None)

        if self.video_script is not None:
            result['videoScript'] = self.video_script.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('index') is not None:
            self.index = m.get('index')

        self.layers = []
        if m.get('layers') is not None:
            for k1 in m.get('layers'):
                temp_model = main_models.SaveAvatarProjectRequestFramesLayers()
                self.layers.append(temp_model.from_map(k1))

        if m.get('videoScript') is not None:
            temp_model = main_models.SaveAvatarProjectRequestFramesVideoScript()
            self.video_script = temp_model.from_map(m.get('videoScript'))

        return self

class SaveAvatarProjectRequestFramesVideoScript(DaraModel):
    def __init__(
        self,
        emotion: str = None,
        pitch_rate: str = None,
        speed_rate: str = None,
        text_content: str = None,
        voice_language: str = None,
        voice_template_id: str = None,
        volume: str = None,
    ):
        self.emotion = emotion
        self.pitch_rate = pitch_rate
        self.speed_rate = speed_rate
        self.text_content = text_content
        self.voice_language = voice_language
        self.voice_template_id = voice_template_id
        self.volume = volume

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.emotion is not None:
            result['emotion'] = self.emotion

        if self.pitch_rate is not None:
            result['pitchRate'] = self.pitch_rate

        if self.speed_rate is not None:
            result['speedRate'] = self.speed_rate

        if self.text_content is not None:
            result['textContent'] = self.text_content

        if self.voice_language is not None:
            result['voiceLanguage'] = self.voice_language

        if self.voice_template_id is not None:
            result['voiceTemplateId'] = self.voice_template_id

        if self.volume is not None:
            result['volume'] = self.volume

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('emotion') is not None:
            self.emotion = m.get('emotion')

        if m.get('pitchRate') is not None:
            self.pitch_rate = m.get('pitchRate')

        if m.get('speedRate') is not None:
            self.speed_rate = m.get('speedRate')

        if m.get('textContent') is not None:
            self.text_content = m.get('textContent')

        if m.get('voiceLanguage') is not None:
            self.voice_language = m.get('voiceLanguage')

        if m.get('voiceTemplateId') is not None:
            self.voice_template_id = m.get('voiceTemplateId')

        if m.get('volume') is not None:
            self.volume = m.get('volume')

        return self

class SaveAvatarProjectRequestFramesLayers(DaraModel):
    def __init__(
        self,
        height: int = None,
        index: int = None,
        material: main_models.SaveAvatarProjectRequestFramesLayersMaterial = None,
        position_x: int = None,
        position_y: int = None,
        type: str = None,
        width: int = None,
    ):
        self.height = height
        self.index = index
        self.material = material
        self.position_x = position_x
        self.position_y = position_y
        self.type = type
        self.width = width

    def validate(self):
        if self.material:
            self.material.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.height is not None:
            result['height'] = self.height

        if self.index is not None:
            result['index'] = self.index

        if self.material is not None:
            result['material'] = self.material.to_map()

        if self.position_x is not None:
            result['positionX'] = self.position_x

        if self.position_y is not None:
            result['positionY'] = self.position_y

        if self.type is not None:
            result['type'] = self.type

        if self.width is not None:
            result['width'] = self.width

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('height') is not None:
            self.height = m.get('height')

        if m.get('index') is not None:
            self.index = m.get('index')

        if m.get('material') is not None:
            temp_model = main_models.SaveAvatarProjectRequestFramesLayersMaterial()
            self.material = temp_model.from_map(m.get('material'))

        if m.get('positionX') is not None:
            self.position_x = m.get('positionX')

        if m.get('positionY') is not None:
            self.position_y = m.get('positionY')

        if m.get('type') is not None:
            self.type = m.get('type')

        if m.get('width') is not None:
            self.width = m.get('width')

        return self

class SaveAvatarProjectRequestFramesLayersMaterial(DaraModel):
    def __init__(
        self,
        format: str = None,
        id: str = None,
        url: str = None,
    ):
        self.format = format
        self.id = id
        self.url = url

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.format is not None:
            result['format'] = self.format

        if self.id is not None:
            result['id'] = self.id

        if self.url is not None:
            result['url'] = self.url

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('format') is not None:
            self.format = m.get('format')

        if m.get('id') is not None:
            self.id = m.get('id')

        if m.get('url') is not None:
            self.url = m.get('url')

        return self

